#
# PySNMP MIB module OPT-IF-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/OPT-IF-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:22:58 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsIntersection, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsIntersection", "ConstraintsUnion", "ValueRangeConstraint")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( ModuleIdentity, MibIdentifier, Counter64, iso, Unsigned32, Gauge32, transmission, Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, IpAddress, Counter32, TimeTicks, ObjectIdentity, Bits, NotificationType, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "MibIdentifier", "Counter64", "iso", "Unsigned32", "Gauge32", "transmission", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "IpAddress", "Counter32", "TimeTicks", "ObjectIdentity", "Bits", "NotificationType")
( RowPointer, RowStatus, TextualConvention, DisplayString, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowPointer", "RowStatus", "TextualConvention", "DisplayString", "TruthValue")
optIfMibModule = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 133)).setRevisions(("2003-08-13 00:00",))
if mibBuilder.loadTexts: optIfMibModule.setLastUpdated('200308130000Z')
if mibBuilder.loadTexts: optIfMibModule.setOrganization('IETF AToM MIB Working Group')
if mibBuilder.loadTexts: optIfMibModule.setContactInfo('WG charter:\n          http://www.ietf.org/html.charters/atommib-charter.html\n\n        Mailing Lists:\n           General Discussion: atommib@research.telcordia.com\n           To Subscribe: atommib-request@research.telcordia.com\n\n\n\n\n\n        Editor: Hing-Kam Lam\n        Postal: Lucent Technologies, Room 4C-616\n                101 Crawfords Corner Road\n                Holmdel, NJ 07733\n           Tel: +1 732 949 8338\n         Email: hklam@lucent.com')
if mibBuilder.loadTexts: optIfMibModule.setDescription('The MIB module to describe pre-OTN and OTN interfaces.\n\n        Copyright (C) The Internet Society (2003).  This version\n        of this MIB module is part of RFC 3591;  see the RFC\n        itself for full legal notices.')
class OptIfAcTI(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(64,64)
    fixedLength = 64

class OptIfBitRateK(Integer32, TextualConvention):
    pass

class OptIfDEGM(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(2,10)

class OptIfDEGThr(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(1,100)

class OptIfDirectionality(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("sink", 1), ("source", 2), ("bidirectional", 3),)

class OptIfSinkOrSource(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("sink", 1), ("source", 2),)

class OptIfExDAPI(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(16,16)
    fixedLength = 16

class OptIfExSAPI(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(16,16)
    fixedLength = 16

class OptIfIntervalNumber(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(1,96)

class OptIfTIMDetMode(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))
    namedValues = NamedValues(("off", 1), ("dapi", 2), ("sapi", 3), ("both", 4),)

class OptIfTxTI(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(64,64)
    fixedLength = 64

optIfObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 1))
optIfConfs = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 2))
optIfOTMn = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 1, 1))
optIfPerfMon = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 1, 2))
optIfOTSn = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 1, 3))
optIfOMSn = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 1, 4))
optIfOChGroup = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 1, 5))
optIfOCh = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 1, 6))
optIfOTUk = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 1, 7))
optIfODUk = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 1, 8))
optIfODUkT = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 1, 9))
optIfGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 2, 1))
optIfCompl = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 133, 2, 2))
optIfOTMnTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 1, 1), )
if mibBuilder.loadTexts: optIfOTMnTable.setDescription('A table of OTMn structure information.')
optIfOTMnEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOTMnEntry.setDescription('A conceptual row that contains the OTMn structure\n     information of an optical interface.')
optIfOTMnOrder = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 1, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,900))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTMnOrder.setDescription('This object indicates the order of the OTM, which\n     represents the maximum number of wavelengths that can be\n     supported at the bit rate(s) supported on the interface.')
optIfOTMnReduced = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 1, 1, 1, 2), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTMnReduced.setDescription('This object indicates whether a reduced or full\n     functionality is supported at the interface.  A value of\n     true means reduced.  A value of false means full.')
optIfOTMnBitRates = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 1, 1, 1, 3), Bits().clone(namedValues=NamedValues(("bitRateK1", 0), ("bitRateK2", 1), ("bitRateK3", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTMnBitRates.setDescription('This attribute is a bit map representing the bit\n     rate or set of bit rates supported on the interface.\n     The meaning of each bit position is as follows:\n       bitRateK1(0) is set if the 2.5 Gbit/s rate is supported\n       bitRateK2(1) is set if the 10 Gbit/s rate is supported\n       bitRateK3(2) is set if the 40 Gbit/s rate is supported\n     Note that each bit position corresponds to one possible\n     value of the type OptIfBitRateK.\n     The default value of this attribute is system specific.')
optIfOTMnInterfaceType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 1, 1, 1, 4), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTMnInterfaceType.setDescription("This object identifies the type of interface.  The value of\n     this attribute will affect the behavior of the OTM with\n     respect to presence/absence of OTM Overhead Signal (OOS)\n     processing and TCM activation.  For an IrDI interface,\n     there is no OOS processing and TCM activation is limited\n     to n levels as specified by a TCM level threshold.\n\n     This object contains two fields that are separated by\n     whitespace.  The possible values are:\n          field 1: one of the 4-character ASCII strings\n                    'IrDI' or 'IaDI'\n          field 2: free-form text consisting of printable\n                   UTF-8 encoded characters\n\n     Note that field 2 is optional.  If it is not present then there\n     is no requirement for trailing whitespace after field 1.\n\n     The default values are as follows:\n          field 1:  'IaDI'\n          field 2: an empty string.")
optIfOTMnTcmMax = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 1, 1, 1, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,6))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTMnTcmMax.setDescription("This object identifies the maximum number of TCM\n     levels allowed for any Optical Channel contained\n     in this OTM.  A new TCM activation will be rejected\n     if the requested level is greater than the threshold.\n     If InterfaceType object specifies a type of 'IaDI'\n     for this OTM, then this attribute is irrelevant.\n\n     Possible values:  unsigned integers in the range\n                       from 0 to 6 inclusive.\n     Default value:    3.")
optIfOTMnOpticalReach = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 1, 1, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("intraOffice", 1), ("shortHaul", 2), ("longHaul", 3), ("veryLongHaul", 4), ("ultraLongHaul", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTMnOpticalReach.setDescription('This object indicates the length the optical signal\n     may travel before requiring termination or regeneration.\n     The meaning of the enumeration are:\n       intraOffice(1)  - intra-office (as defined in ITU-T G.957)\n       shortHaul(2)    - short haul (as defined in ITU-T G.957)\n       longHaul(3)     - long haul (as defined in ITU-T G.957)\n       veryLongHaul(4) - very long haul (as defined in ITU-T G.691)\n       ultraLongHaul(5)- ultra long haul (as defined in ITU-T G.691)')
optIfPerfMonIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 2, 1), )
if mibBuilder.loadTexts: optIfPerfMonIntervalTable.setDescription('A table of 15-minute performance monitoring interval\n     information.')
optIfPerfMonIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 2, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfPerfMonIntervalEntry.setDescription('A conceptual row that contains 15-minute performance\n     monitoring interval information of an interface.')
optIfPerfMonCurrentTimeElapsed = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 2, 1, 1, 1), Gauge32().subtype(subtypeSpec=ValueRangeConstraint(0,900))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfPerfMonCurrentTimeElapsed.setDescription("Number of seconds elapsed in the current 15-minute\n     performance monitoring interval.\n     If, for some reason, such as an adjustment in the NE's\n     time-of-day clock, the number of seconds elapsed exceeds\n     the maximum value, then the maximum value will be returned.")
optIfPerfMonCurDayTimeElapsed = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 2, 1, 1, 2), Gauge32().subtype(subtypeSpec=ValueRangeConstraint(0,86400))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfPerfMonCurDayTimeElapsed.setDescription("Number of seconds elapsed in the current 24-hour interval\n     performance monitoring period.\n     If, for some reason, such as an adjustment in the NE's\n     time-of-day clock, the number of seconds elapsed exceeds\n     the maximum value, then the maximum value will be returned.")
optIfPerfMonIntervalNumIntervals = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 2, 1, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,96))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfPerfMonIntervalNumIntervals.setDescription('The number of 15-minute intervals for which performance\n     monitoring data is available.  The number is the same for all\n     the associated sub layers of the interface.\n\n\n\n     An optical interface must be capable of supporting at least\n     n intervals, where n is defined as follows:\n         The minimum value of n is 4.\n         The default of n is 32.\n         The maximum value of n is 96.\n\n     The value of this object will be n unless performance\n     monitoring was (re-)started for the interface within the last\n     (n*15) minutes, in which case the value will be the number of\n     complete 15-minute intervals since measurement was\n     (re-)started.')
optIfPerfMonIntervalNumInvalidIntervals = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 2, 1, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,96))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfPerfMonIntervalNumInvalidIntervals.setDescription('The number of intervals in the range from 0 to\n     optIfPerfMonIntervalNumIntervals for which no performance\n     monitoring data is available and/or the data is invalid.')
optIfOTSnConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1), )
if mibBuilder.loadTexts: optIfOTSnConfigTable.setDescription('A table of OTSn configuration information.')
optIfOTSnConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOTSnConfigEntry.setDescription('A conceptual row that contains OTSn configuration\n     information of an interface.')
optIfOTSnDirectionality = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1, 1), OptIfDirectionality()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnDirectionality.setDescription('Indicates the directionality of the entity.')
optIfOTSnAprStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1, 2), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnAprStatus.setDescription("This attribute indicates the status of the Automatic\n     Power Reduction (APR) function of the entity.  Valid\n     values are 'on' and 'off'.")
optIfOTSnAprControl = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1, 3), SnmpAdminString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnAprControl.setDescription('This object is a UTF-8 encoded string that specifies Automatic\n     Power Reduction (APR) control actions requested of this entity\n     (when written) and that returns the current APR control state\n     of this entity (when read).  The values are implementation-defined.\n     Any implementation that instantiates this object must document the\n     set of values that it allows to be written, the set of values\n     that it will return, and what each of those values means.')
optIfOTSnTraceIdentifierTransmitted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1, 4), OptIfTxTI()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnTraceIdentifierTransmitted.setDescription("The trace identifier transmitted.\n     This object is applicable when optIfOTSnDirectionality has the\n     value source(2) or bidirectional(3).\n     This object does not apply to reduced-capability systems (i.e.,\n     those for which optIfOTMnReduced has the value true(1)) or\n     at IrDI interfaces (i.e., when optIfOTMnInterfaceType field 1\n     has the value 'IrDI').\n     If no value is ever set by a management entity for the object\n     optIfOTSnTraceIdentifierTransmitted, system-specific default\n     value will be used.  Any implementation that instantiates this\n     object must document the system-specific default value or how it\n     is derived.")
optIfOTSnDAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1, 5), OptIfExDAPI()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnDAPIExpected.setDescription("The DAPI expected by the receiver.\n     This object is applicable when optIfOTSnDirectionality has the\n     value sink(1) or bidirectional(3).  It has no effect if\n     optIfOTSnTIMDetMode has the value off(1) or sapi(3).\n     This object does not apply to reduced-capability systems (i.e.,\n     those for which optIfOTMnReduced has the value true(1)) or\n     at IrDI interfaces (i.e., when optIfOTMnInterfaceType field 1\n     has the value 'IrDI').")
optIfOTSnSAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1, 6), OptIfExSAPI()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnSAPIExpected.setDescription("The SAPI expected by the receiver.\n     This object is applicable when optIfOTSnDirectionality has the\n     value sink(1) or bidirectional(3).  It has no effect if\n     optIfOTSnTIMDetMode has the value off(1) or dapi(2).\n     This object does not apply to reduced-capability systems (i.e.,\n     those for which optIfOTMnReduced has the value true(1)) or\n     at IrDI interfaces (i.e., when optIfOTMnInterfaceType field 1\n     has the value 'IrDI').")
optIfOTSnTraceIdentifierAccepted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1, 7), OptIfAcTI()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnTraceIdentifierAccepted.setDescription("The actual trace identifier received.\n     This object is applicable when optIfOTSnDirectionality has the\n     value sink(1) or bidirectional(3).  Its value is unspecified\n     if optIfOTSnCurrentStatus has either or both of the\n     losO(5) and los(6) bits set.\n     This object does not apply to reduced-capability systems (i.e.,\n     those for which optIfOTMnReduced has the value true(1)) or\n     at IrDI interfaces (i.e., when optIfOTMnInterfaceType field 1\n     has the value 'IrDI').")
optIfOTSnTIMDetMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1, 8), OptIfTIMDetMode()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnTIMDetMode.setDescription("Indicates the mode of the Trace Identifier Mismatch (TIM)\n     Detection function.  This object is applicable\n     when optIfOTSnDirectionality has the value sink(1)\n     or bidirectional(3).  The default value is off(1).\n     This object does not apply to reduced-capability systems (i.e.,\n     those for which optIfOTMnReduced has the value true(1)) or\n     at IrDI interfaces (i.e., when optIfOTMnInterfaceType field 1\n     has the value 'IrDI').\n     The default value of this object is off(1).")
optIfOTSnTIMActEnabled = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1, 9), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnTIMActEnabled.setDescription("Indicates whether the Trace Identifier Mismatch (TIM)\n     Consequent Action function is enabled.  This object\n     is applicable when optIfOTSnDirectionality has the\n     value sink(1) or bidirectional(3).  It has no effect\n     when the value of optIfOTSnTIMDetMode is off(1).\n     This object does not apply to reduced-capability systems (i.e.,\n     those for which optIfOTMnReduced has the value true(1)) or\n     at IrDI interfaces (i.e., when optIfOTMnInterfaceType field 1\n     has the value 'IrDI').\n     The default value of this object is false(2).")
optIfOTSnCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 1, 1, 10), Bits().clone(namedValues=NamedValues(("bdiP", 0), ("bdiO", 1), ("bdi", 2), ("tim", 3), ("losP", 4), ("losO", 5), ("los", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnCurrentStatus.setDescription('Indicates the defect condition of the entity, if any.\n     This object is applicable when optIfOTSnDirectionality\n     has the value sink(1) or bidirectional(3).  In\n     reduced-capability systems or at IrDI interfaces\n     the only bit position that may be set is los(6).')
optIfOTSnSinkCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2), )
if mibBuilder.loadTexts: optIfOTSnSinkCurrentTable.setDescription('A table of OTSn sink performance monitoring information for\n     the current 15-minute interval.')
optIfOTSnSinkCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOTSnSinkCurrentEntry.setDescription('A conceptual row that contains OTSn sink performance\n     monitoring information of an interface for the current\n     15-minute interval.')
optIfOTSnSinkCurrentSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOTSnSinkCurrentInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentInputPower.setDescription('The optical power monitored at the input.')
optIfOTSnSinkCurrentLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     current 15-minute interval.')
optIfOTSnSinkCurrentHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentHighInputPower.setDescription('The highest optical power monitored at the input during the\n     current 15-minute interval.')
optIfOTSnSinkCurrentLowerInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentLowerInputPowerThreshold.setDescription('The lower limit threshold on input power.  If\n     optIfOTSnSinkCurrentInputPower drops to this value or below,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOTSnSinkCurrentUpperInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentUpperInputPowerThreshold.setDescription('The upper limit threshold on input power.  If\n     optIfOTSnSinkCurrentInputPower reaches or exceeds this value,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOTSnSinkCurrentOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentOutputPower.setDescription('The optical power monitored at the output.')
optIfOTSnSinkCurrentLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     current 15-minute interval.')
optIfOTSnSinkCurrentHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 9), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     current 15-minute interval.')
optIfOTSnSinkCurrentLowerOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 10), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentLowerOutputPowerThreshold.setDescription('The lower limit threshold on output power.  If\n     optIfOTSnSinkCurrentOutputPower drops to this value or below,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOTSnSinkCurrentUpperOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 2, 1, 11), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnSinkCurrentUpperOutputPowerThreshold.setDescription('The upper limit threshold on output power.  If\n     optIfOTSnSinkCurrentOutputPower reaches or exceeds this value,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOTSnSinkIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 3), )
if mibBuilder.loadTexts: optIfOTSnSinkIntervalTable.setDescription('A table of historical OTSn sink performance monitoring\n     information.')
optIfOTSnSinkIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfOTSnSinkIntervalNumber"))
if mibBuilder.loadTexts: optIfOTSnSinkIntervalEntry.setDescription('A conceptual row that contains OTSn sink performance\n     monitoring information of an interface during a particular\n     historical interval.')
optIfOTSnSinkIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 3, 1, 1), OptIfIntervalNumber())
if mibBuilder.loadTexts: optIfOTSnSinkIntervalNumber.setDescription('Uniquely identifies the interval.')
optIfOTSnSinkIntervalSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 3, 1, 2), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkIntervalSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOTSnSinkIntervalLastInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 3, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkIntervalLastInputPower.setDescription('The last optical power monitored at the input during the\n     interval.')
optIfOTSnSinkIntervalLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 3, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkIntervalLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     interval.')
optIfOTSnSinkIntervalHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 3, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkIntervalHighInputPower.setDescription('The highest optical power monitored at the input during the\n     interval.')
optIfOTSnSinkIntervalLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 3, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkIntervalLastOutputPower.setDescription('The last optical power monitored at the output during the\n     interval.')
optIfOTSnSinkIntervalLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 3, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkIntervalLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     interval.')
optIfOTSnSinkIntervalHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 3, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkIntervalHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     interval.')
optIfOTSnSinkCurDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 4), )
if mibBuilder.loadTexts: optIfOTSnSinkCurDayTable.setDescription('A table of OTSn sink performance monitoring information for\n     the current 24-hour interval.')
optIfOTSnSinkCurDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 4, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOTSnSinkCurDayEntry.setDescription('A conceptual row that contains OTSn sink performance\n     monitoring information of an interface for the current\n     24-hour interval.')
optIfOTSnSinkCurDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 4, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOTSnSinkCurDayLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 4, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurDayLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     current 24-hour interval.')
optIfOTSnSinkCurDayHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 4, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurDayHighInputPower.setDescription('The highest optical power monitored at the input during the\n     current 24-hour interval.')
optIfOTSnSinkCurDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 4, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurDayLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     current 24-hour interval.')
optIfOTSnSinkCurDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 4, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkCurDayHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     current 24-hour interval.')
optIfOTSnSinkPrevDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 5), )
if mibBuilder.loadTexts: optIfOTSnSinkPrevDayTable.setDescription('A table of OTSn sink performance monitoring information for\n     the previous 24-hour interval.')
optIfOTSnSinkPrevDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 5, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOTSnSinkPrevDayEntry.setDescription('A conceptual row that contains OTSn sink performance\n     monitoring information of an interface for the previous\n     24-hour interval.')
optIfOTSnSinkPrevDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 5, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkPrevDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOTSnSinkPrevDayLastInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 5, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkPrevDayLastInputPower.setDescription('The last optical power monitored at the input during the\n     previous 24-hour interval.')
optIfOTSnSinkPrevDayLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 5, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkPrevDayLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     previous 24-hour interval.')
optIfOTSnSinkPrevDayHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 5, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkPrevDayHighInputPower.setDescription('The highest optical power monitored at the input during the\n     previous 24-hour interval.')
optIfOTSnSinkPrevDayLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 5, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkPrevDayLastOutputPower.setDescription('The last optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOTSnSinkPrevDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 5, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkPrevDayLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOTSnSinkPrevDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 5, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSinkPrevDayHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOTSnSrcCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6), )
if mibBuilder.loadTexts: optIfOTSnSrcCurrentTable.setDescription('A table of OTSn source performance monitoring information for\n     the current 15-minute interval.')
optIfOTSnSrcCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOTSnSrcCurrentEntry.setDescription('A conceptual row that contains OTSn source performance\n     monitoring information of an interface for the current\n     15-minute interval.')
optIfOTSnSrcCurrentSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOTSnSrcCurrentOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentOutputPower.setDescription('The optical power monitored at the output.')
optIfOTSnSrcCurrentLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     current 15-minute interval.')
optIfOTSnSrcCurrentHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     current 15-minute interval.')
optIfOTSnSrcCurrentLowerOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentLowerOutputPowerThreshold.setDescription('The lower limit threshold on output power.  If\n     optIfOTSnSrcCurrentOutputPower drops to this value or below,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOTSnSrcCurrentUpperOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentUpperOutputPowerThreshold.setDescription('The upper limit threshold on output power.  If\n     optIfOTSnSrcCurrentOutputPower reaches or exceeds this value,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOTSnSrcCurrentInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentInputPower.setDescription('The optical power monitored at the input.')
optIfOTSnSrcCurrentLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     current 15-minute interval.')
optIfOTSnSrcCurrentHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 9), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentHighInputPower.setDescription('The highest optical power monitored at the input during the\n     current 15-minute interval.')
optIfOTSnSrcCurrentLowerInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 10), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentLowerInputPowerThreshold.setDescription('The lower limit threshold on input power.  If\n     optIfOTSnSrcCurrentInputPower drops to this value or below,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOTSnSrcCurrentUpperInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 6, 1, 11), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTSnSrcCurrentUpperInputPowerThreshold.setDescription('The upper limit threshold on input power.  If\n     optIfOTSnSrcCurrentInputPower reaches or exceeds this value,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOTSnSrcIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 7), )
if mibBuilder.loadTexts: optIfOTSnSrcIntervalTable.setDescription('A table of historical OTSn source performance monitoring\n     information.')
optIfOTSnSrcIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 7, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfOTSnSrcIntervalNumber"))
if mibBuilder.loadTexts: optIfOTSnSrcIntervalEntry.setDescription('A conceptual row that contains OTSn source performance\n     monitoring information of an interface during a particular\n     historical interval.')
optIfOTSnSrcIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 7, 1, 1), OptIfIntervalNumber())
if mibBuilder.loadTexts: optIfOTSnSrcIntervalNumber.setDescription('Uniquely identifies the interval.')
optIfOTSnSrcIntervalSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 7, 1, 2), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcIntervalSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOTSnSrcIntervalLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 7, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcIntervalLastOutputPower.setDescription('The last optical power monitored at the output during the\n     interval.')
optIfOTSnSrcIntervalLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 7, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcIntervalLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     interval.')
optIfOTSnSrcIntervalHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 7, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcIntervalHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     interval.')
optIfOTSnSrcIntervalLastInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 7, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcIntervalLastInputPower.setDescription('The last optical power monitored at the input during the\n     interval.')
optIfOTSnSrcIntervalLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 7, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcIntervalLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     interval.')
optIfOTSnSrcIntervalHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 7, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcIntervalHighInputPower.setDescription('The highest optical power monitored at the input during the\n     interval.')
optIfOTSnSrcCurDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 8), )
if mibBuilder.loadTexts: optIfOTSnSrcCurDayTable.setDescription('A table of OTSn source performance monitoring information for\n     the current 24-hour interval.')
optIfOTSnSrcCurDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 8, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOTSnSrcCurDayEntry.setDescription('A conceptual row that contains OTSn source performance\n     monitoring information of an interface for the current\n     24-hour interval.')
optIfOTSnSrcCurDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 8, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOTSnSrcCurDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 8, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurDayLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     current 24-hour interval.')
optIfOTSnSrcCurDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 8, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurDayHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     current 24-hour interval.')
optIfOTSnSrcCurDayLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 8, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurDayLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     current 24-hour interval.')
optIfOTSnSrcCurDayHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 8, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcCurDayHighInputPower.setDescription('The highest optical power monitored at the input during the\n     current 24-hour interval.')
optIfOTSnSrcPrevDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 9), )
if mibBuilder.loadTexts: optIfOTSnSrcPrevDayTable.setDescription('A table of OTSn source performance monitoring information for\n     the previous 24-hour interval.')
optIfOTSnSrcPrevDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 9, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOTSnSrcPrevDayEntry.setDescription('A conceptual row that contains OTSn source performance\n     monitoring information of an interface for the previous\n     24-hour interval.')
optIfOTSnSrcPrevDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 9, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcPrevDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOTSnSrcPrevDayLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 9, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcPrevDayLastOutputPower.setDescription('The last optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOTSnSrcPrevDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 9, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcPrevDayLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOTSnSrcPrevDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 9, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcPrevDayHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOTSnSrcPrevDayLastInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 9, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcPrevDayLastInputPower.setDescription('The last optical power monitored at the input during the\n     previous 24-hour interval.')
optIfOTSnSrcPrevDayLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 9, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcPrevDayLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     previous 24-hour interval.')
optIfOTSnSrcPrevDayHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 3, 9, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTSnSrcPrevDayHighInputPower.setDescription('The highest optical power monitored at the input during the\n     previous 24-hour interval.')
optIfOMSnConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 1), )
if mibBuilder.loadTexts: optIfOMSnConfigTable.setDescription('A table of OMSn configuration information.')
optIfOMSnConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOMSnConfigEntry.setDescription('A conceptual row that contains OMSn configuration\n     information of an interface.')
optIfOMSnDirectionality = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 1, 1, 1), OptIfDirectionality()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnDirectionality.setDescription('Indicates the directionality of the entity.')
optIfOMSnCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 1, 1, 2), Bits().clone(namedValues=NamedValues(("ssfP", 0), ("ssfO", 1), ("ssf", 2), ("bdiP", 3), ("bdiO", 4), ("bdi", 5), ("losP", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnCurrentStatus.setDescription('Indicates the defect condition of the entity, if any.\n     This object is applicable only to full capability\n     systems whose interface type is IaDI and for which\n\n\n\n     optIfOMSnDirectionality has the value sink(1) or\n     bidirectional(3).')
optIfOMSnSinkCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2), )
if mibBuilder.loadTexts: optIfOMSnSinkCurrentTable.setDescription('A table of OMSn sink performance monitoring information for\n     the current 15-minute interval.')
optIfOMSnSinkCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOMSnSinkCurrentEntry.setDescription('A conceptual row that contains OMSn sink performance\n     monitoring information of an interface for the current\n     15-minute interval.')
optIfOMSnSinkCurrentSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOMSnSinkCurrentAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentAggregatedInputPower.setDescription('The aggregated optical power of all the DWDM input\n     channels.')
optIfOMSnSinkCurrentLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentLowAggregatedInputPower.setDescription('The lowest aggregated optical power of all the DWDM input\n     channels during the current 15-minute interval.')
optIfOMSnSinkCurrentHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentHighAggregatedInputPower.setDescription('The highest aggregated optical power of all the DWDM input\n     channels during the current 15-minute interval.')
optIfOMSnSinkCurrentLowerInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentLowerInputPowerThreshold.setDescription('The lower limit threshold on aggregated input power.  If\n     optIfOMSnSinkCurrentAggregatedInputPower drops to this value\n     or below, a Threshold Crossing Alert (TCA) should be sent.')
optIfOMSnSinkCurrentUpperInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentUpperInputPowerThreshold.setDescription('The upper limit threshold on aggregated input power.  If\n     optIfOMSnSinkCurrentAggregatedInputPower reaches or exceeds\n     this value, a Threshold Crossing Alert (TCA) should be sent.')
optIfOMSnSinkCurrentOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentOutputPower.setDescription('The optical power monitored at the output.')
optIfOMSnSinkCurrentLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentLowOutputPower.setDescription('The lowest optical power monitored at the output\n     during the current 15-minute interval.')
optIfOMSnSinkCurrentHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 9), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentHighOutputPower.setDescription('The highest optical power monitored at the output\n     during the current 15-minute interval.')
optIfOMSnSinkCurrentLowerOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 10), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentLowerOutputPowerThreshold.setDescription('The lower limit threshold on output power.  If\n     optIfOMSnSinkCurrentOutputPower drops to this value\n     or below, a Threshold Crossing Alert (TCA) should be sent.')
optIfOMSnSinkCurrentUpperOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 2, 1, 11), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOMSnSinkCurrentUpperOutputPowerThreshold.setDescription('The upper limit threshold on output power.  If\n     optIfOMSnSinkCurrentOutputPower reaches or exceeds\n     this value, a Threshold Crossing Alert (TCA) should be sent.')
optIfOMSnSinkIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 3), )
if mibBuilder.loadTexts: optIfOMSnSinkIntervalTable.setDescription('A table of historical OMSn sink performance monitoring\n     information.')
optIfOMSnSinkIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfOMSnSinkIntervalNumber"))
if mibBuilder.loadTexts: optIfOMSnSinkIntervalEntry.setDescription('A conceptual row that contains OMSn sink performance\n     monitoring information of an interface during a particular\n     historical interval.')
optIfOMSnSinkIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 3, 1, 1), OptIfIntervalNumber())
if mibBuilder.loadTexts: optIfOMSnSinkIntervalNumber.setDescription('Uniquely identifies the interval.')
optIfOMSnSinkIntervalSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 3, 1, 2), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkIntervalSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOMSnSinkIntervalLastAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 3, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkIntervalLastAggregatedInputPower.setDescription('The last aggregated optical power of all the DWDM input\n     channels during the interval.')
optIfOMSnSinkIntervalLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 3, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkIntervalLowAggregatedInputPower.setDescription('The lowest aggregated optical power of all the DWDM input\n     channels during the interval.')
optIfOMSnSinkIntervalHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 3, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkIntervalHighAggregatedInputPower.setDescription('The highest aggregated optical power of all the DWDM input\n     channels during the interval.')
optIfOMSnSinkIntervalLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 3, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkIntervalLastOutputPower.setDescription('The last optical power at the output\n     during the interval.')
optIfOMSnSinkIntervalLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 3, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkIntervalLowOutputPower.setDescription('The lowest optical power at the output\n     during the interval.')
optIfOMSnSinkIntervalHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 3, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkIntervalHighOutputPower.setDescription('The highest optical power at the output\n     during the interval.')
optIfOMSnSinkCurDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 4), )
if mibBuilder.loadTexts: optIfOMSnSinkCurDayTable.setDescription('A table of OMSn sink performance monitoring information for\n     the current 24-hour interval.')
optIfOMSnSinkCurDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 4, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOMSnSinkCurDayEntry.setDescription('A conceptual row that contains OMSn sink performance\n     monitoring information of an interface for the current\n     24-hour interval.')
optIfOMSnSinkCurDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 4, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOMSnSinkCurDayLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 4, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurDayLowAggregatedInputPower.setDescription('The lowest aggregated optical power of all the DWDM input\n     channels during the current 24-hour interval.')
optIfOMSnSinkCurDayHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 4, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurDayHighAggregatedInputPower.setDescription('The highest aggregated optical power of all the DWDM input\n     channels during the current 24-hour interval.')
optIfOMSnSinkCurDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 4, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurDayLowOutputPower.setDescription('The lowest optical power at the output\n     during the current 24-hour interval.')
optIfOMSnSinkCurDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 4, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkCurDayHighOutputPower.setDescription('The highest  optical power at the output\n     during the current 24-hour interval.')
optIfOMSnSinkPrevDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 5), )
if mibBuilder.loadTexts: optIfOMSnSinkPrevDayTable.setDescription('A table of OMSn sink performance monitoring information for\n     the previous 24-hour interval.')
optIfOMSnSinkPrevDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 5, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOMSnSinkPrevDayEntry.setDescription('A conceptual row that contains OMSn sink performance\n     monitoring information of an interface for the previous\n     24-hour interval.')
optIfOMSnSinkPrevDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 5, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkPrevDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOMSnSinkPrevDayLastAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 5, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkPrevDayLastAggregatedInputPower.setDescription('The last aggregated optical power of all the DWDM input\n     channels during the previous 24-hour interval.')
optIfOMSnSinkPrevDayLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 5, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkPrevDayLowAggregatedInputPower.setDescription('The lowest aggregated optical power of all the DWDM input\n     channels during the previous 24-hour interval.')
optIfOMSnSinkPrevDayHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 5, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkPrevDayHighAggregatedInputPower.setDescription('The highest aggregated optical power of all the DWDM input\n     channels during the previous 24-hour interval.')
optIfOMSnSinkPrevDayLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 5, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkPrevDayLastOutputPower.setDescription('The last  optical power at the output\n     during the previous 24-hour interval.')
optIfOMSnSinkPrevDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 5, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkPrevDayLowOutputPower.setDescription('The lowest optical power at the output\n     during the previous 24-hour interval.')
optIfOMSnSinkPrevDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 5, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSinkPrevDayHighOutputPower.setDescription('The highest optical power at the output\n     during the previous 24-hour interval.')
optIfOMSnSrcCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6), )
if mibBuilder.loadTexts: optIfOMSnSrcCurrentTable.setDescription('A table of OMSn source performance monitoring information for\n     the current 15-minute interval.')
optIfOMSnSrcCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOMSnSrcCurrentEntry.setDescription('A conceptual row that contains OMSn source performance\n     monitoring information of an interface for the current\n     15-minute interval.')
optIfOMSnSrcCurrentSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOMSnSrcCurrentOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentOutputPower.setDescription('The optical power monitored at the output.')
optIfOMSnSrcCurrentLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     current 15-minute interval.')
optIfOMSnSrcCurrentHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     current 15-minute interval.')
optIfOMSnSrcCurrentLowerOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentLowerOutputPowerThreshold.setDescription('The lower limit threshold on output power.  If\n     optIfOMSnSrcCurrentOutputPower drops to this value or below,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOMSnSrcCurrentUpperOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentUpperOutputPowerThreshold.setDescription('The upper limit threshold on output power.  If\n     optIfOMSnSrcCurrentOutputPower reaches or exceeds this value,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOMSnSrcCurrentAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentAggregatedInputPower.setDescription('The aggregated optical power at the input.')
optIfOMSnSrcCurrentLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentLowAggregatedInputPower.setDescription('The lowest aggregated optical power at the input\n     during the current 15-minute interval.')
optIfOMSnSrcCurrentHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 9), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentHighAggregatedInputPower.setDescription('The highest aggregated optical power at the input\n     during the current 15-minute interval.')
optIfOMSnSrcCurrentLowerInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 10), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentLowerInputPowerThreshold.setDescription('The lower limit threshold on aggregated input power.  If\n     optIfOMSnSrcCurrentAggregatedInputPower drops to this value\n     or below, a Threshold Crossing Alert (TCA) should be sent.')
optIfOMSnSrcCurrentUpperInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 6, 1, 11), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOMSnSrcCurrentUpperInputPowerThreshold.setDescription('The upper limit threshold on aggregated input power.  If\n     optIfOMSnSrcCurrentAggregatedInputPower reaches or exceeds\n     this value, a Threshold Crossing Alert (TCA) should be sent.')
optIfOMSnSrcIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 7), )
if mibBuilder.loadTexts: optIfOMSnSrcIntervalTable.setDescription('A table of historical OMSn source performance monitoring\n     information.')
optIfOMSnSrcIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 7, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfOMSnSrcIntervalNumber"))
if mibBuilder.loadTexts: optIfOMSnSrcIntervalEntry.setDescription('A conceptual row that contains OMSn source performance\n     monitoring information of an interface during a particular\n     historical interval.')
optIfOMSnSrcIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 7, 1, 1), OptIfIntervalNumber())
if mibBuilder.loadTexts: optIfOMSnSrcIntervalNumber.setDescription('Uniquely identifies the interval.')
optIfOMSnSrcIntervalSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 7, 1, 2), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcIntervalSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOMSnSrcIntervalLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 7, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcIntervalLastOutputPower.setDescription('The last optical power monitored at the output during the\n     interval.')
optIfOMSnSrcIntervalLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 7, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcIntervalLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     interval.')
optIfOMSnSrcIntervalHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 7, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcIntervalHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     interval.')
optIfOMSnSrcIntervalLastAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 7, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcIntervalLastAggregatedInputPower.setDescription('The last aggregated optical power at the input\n     during the interval.')
optIfOMSnSrcIntervalLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 7, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcIntervalLowAggregatedInputPower.setDescription('The lowest aggregated optical power at the input\n     during the interval.')
optIfOMSnSrcIntervalHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 7, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcIntervalHighAggregatedInputPower.setDescription('The highest aggregated optical power at the input\n     during the interval.')
optIfOMSnSrcCurDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 8), )
if mibBuilder.loadTexts: optIfOMSnSrcCurDayTable.setDescription('A table of OMSn source performance monitoring information for\n     the current 24-hour interval.')
optIfOMSnSrcCurDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 8, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOMSnSrcCurDayEntry.setDescription('A conceptual row that contains OMSn source performance\n     monitoring information of an interface for the current\n     24-hour interval.')
optIfOMSnSrcCurDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 8, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOMSnSrcCurDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 8, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurDayLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     current 24-hour interval.')
optIfOMSnSrcCurDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 8, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurDayHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     current 24-hour interval.')
optIfOMSnSrcCurDayLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 8, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurDayLowAggregatedInputPower.setDescription('The lowest aggregated optical power at the input\n     during the current 24-hour interval.')
optIfOMSnSrcCurDayHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 8, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcCurDayHighAggregatedInputPower.setDescription('The highest aggregated optical power at the input\n     during the current 24-hour interval.')
optIfOMSnSrcPrevDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 9), )
if mibBuilder.loadTexts: optIfOMSnSrcPrevDayTable.setDescription('A table of OMSn source performance monitoring information for\n     the previous 24-hour interval.')
optIfOMSnSrcPrevDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 9, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOMSnSrcPrevDayEntry.setDescription('A conceptual row that contains OMSn source performance\n     monitoring information of an interface for the previous\n     24-hour interval.')
optIfOMSnSrcPrevDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 9, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcPrevDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOMSnSrcPrevDayLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 9, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcPrevDayLastOutputPower.setDescription('The last optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOMSnSrcPrevDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 9, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcPrevDayLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOMSnSrcPrevDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 9, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcPrevDayHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOMSnSrcPrevDayLastAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 9, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcPrevDayLastAggregatedInputPower.setDescription('The last aggregated optical power at the input during the\n     previous 24-hour interval.')
optIfOMSnSrcPrevDayLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 9, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcPrevDayLowAggregatedInputPower.setDescription('The lowest aggregated optical power at the input during the\n     previous 24-hour interval.')
optIfOMSnSrcPrevDayHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 4, 9, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOMSnSrcPrevDayHighAggregatedInputPower.setDescription('The highest aggregated optical power at the input during the\n     previous 24-hour interval.')
optIfOChGroupConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 1), )
if mibBuilder.loadTexts: optIfOChGroupConfigTable.setDescription('A table of OChGroup configuration information.')
optIfOChGroupConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChGroupConfigEntry.setDescription('A conceptual row that contains OChGroup configuration\n     information of an interface.')
optIfOChGroupDirectionality = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 1, 1, 1), OptIfDirectionality()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupDirectionality.setDescription('Indicates the directionality of the entity.')
optIfOChGroupSinkCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2), )
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentTable.setDescription('A table of OChGroup sink performance monitoring information for\n     the current 15-minute interval.')
optIfOChGroupSinkCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentEntry.setDescription('A conceptual row that contains OChGroup sink performance\n     monitoring information of an interface for the current\n     15-minute interval.')
optIfOChGroupSinkCurrentSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChGroupSinkCurrentAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentAggregatedInputPower.setDescription('The aggregated optical power of all the DWDM input\n     channels in the OChGroup.')
optIfOChGroupSinkCurrentLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentLowAggregatedInputPower.setDescription('The lowest aggregated optical power of all the DWDM input\n     channels in the OChGroup during the current 15-minute interval.')
optIfOChGroupSinkCurrentHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentHighAggregatedInputPower.setDescription('The highest aggregated optical power of all the DWDM input\n     channels in the OChGroup during the current 15-minute interval.')
optIfOChGroupSinkCurrentLowerInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentLowerInputPowerThreshold.setDescription('The lower limit threshold on aggregated input power.  If\n     optIfOChGroupSinkCurrentAggregatedInputPower drops to this value\n     or below, a Threshold Crossing Alert (TCA) should be sent.')
optIfOChGroupSinkCurrentUpperInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentUpperInputPowerThreshold.setDescription('The upper limit threshold on aggregated input power.  If\n     optIfOChGroupSinkCurrentAggregatedInputPower reaches or exceeds\n     this value, a Threshold Crossing Alert (TCA) should be sent.')
optIfOChGroupSinkCurrentOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentOutputPower.setDescription('The optical power monitored at the output\n     in the OChGroup.')
optIfOChGroupSinkCurrentLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentLowOutputPower.setDescription('The lowest optical power monitored at the output\n     in the OChGroup during the current 15-minute interval.')
optIfOChGroupSinkCurrentHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 9), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentHighOutputPower.setDescription('The highest optical power monitored at the output\n     in the OChGroup during the current 15-minute interval.')
optIfOChGroupSinkCurrentLowerOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 10), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentLowerOutputPowerThreshold.setDescription('The lower limit threshold on the output power.  If\n     optIfOChGroupSinkCurrentOutputPower drops to this value\n     or below, a Threshold Crossing Alert (TCA) should be sent.')
optIfOChGroupSinkCurrentUpperOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 2, 1, 11), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChGroupSinkCurrentUpperOutputPowerThreshold.setDescription('The upper limit threshold on the output power.  If\n     optIfOChGroupSinkCurrentOutputPower reaches or exceeds\n     this value, a Threshold Crossing Alert (TCA) should be sent.')
optIfOChGroupSinkIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 3), )
if mibBuilder.loadTexts: optIfOChGroupSinkIntervalTable.setDescription('A table of historical OChGroup sink performance monitoring\n     information.')
optIfOChGroupSinkIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfOChGroupSinkIntervalNumber"))
if mibBuilder.loadTexts: optIfOChGroupSinkIntervalEntry.setDescription('A conceptual row that contains OChGroup sink performance\n     monitoring information of an interface during a particular\n     historical interval.')
optIfOChGroupSinkIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 3, 1, 1), OptIfIntervalNumber())
if mibBuilder.loadTexts: optIfOChGroupSinkIntervalNumber.setDescription('Uniquely identifies the interval.')
optIfOChGroupSinkIntervalSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 3, 1, 2), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkIntervalSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChGroupSinkIntervalLastAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 3, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkIntervalLastAggregatedInputPower.setDescription('The last aggregated optical power of all the DWDM input\n     channels in the OChGroup during the interval.')
optIfOChGroupSinkIntervalLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 3, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkIntervalLowAggregatedInputPower.setDescription('The lowest aggregated optical power of all the DWDM input\n     channels in the OChGroup during the interval.')
optIfOChGroupSinkIntervalHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 3, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkIntervalHighAggregatedInputPower.setDescription('The highest aggregated optical power of all the DWDM input\n     channels in the OChGroup during the interval.')
optIfOChGroupSinkIntervalLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 3, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkIntervalLastOutputPower.setDescription('The last optical power monitored at the output\n     in the OChGroup during the interval.')
optIfOChGroupSinkIntervalLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 3, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkIntervalLowOutputPower.setDescription('The lowest optical power monitored at the output\n     in the OChGroup during the interval.')
optIfOChGroupSinkIntervalHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 3, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkIntervalHighOutputPower.setDescription('The highest optical power monitored at the output\n     in the OChGroup during the interval.')
optIfOChGroupSinkCurDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 4), )
if mibBuilder.loadTexts: optIfOChGroupSinkCurDayTable.setDescription('A table of OChGroup sink performance monitoring information for\n     the current 24-hour interval.')
optIfOChGroupSinkCurDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 4, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChGroupSinkCurDayEntry.setDescription('A conceptual row that contains OChGroup sink performance\n     monitoring information of an interface for the current\n     24-hour interval.')
optIfOChGroupSinkCurDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 4, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChGroupSinkCurDayLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 4, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurDayLowAggregatedInputPower.setDescription('The lowest aggregated optical power of all the DWDM input\n     channels in the OChGroup during the current 24-hour interval.')
optIfOChGroupSinkCurDayHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 4, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurDayHighAggregatedInputPower.setDescription('The highest aggregated optical power of all the DWDM input\n     channels in the OChGroup during the current 24-hour interval.')
optIfOChGroupSinkCurDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 4, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurDayLowOutputPower.setDescription('The lowest optical power monitored at the output\n     in the OChGroup during the current 24-hour interval.')
optIfOChGroupSinkCurDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 4, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkCurDayHighOutputPower.setDescription('The highest optical power monitored at the output\n     in the OChGroup during the current 24-hour interval.')
optIfOChGroupSinkPrevDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 5), )
if mibBuilder.loadTexts: optIfOChGroupSinkPrevDayTable.setDescription('A table of OChGroup sink performance monitoring information for\n     the previous 24-hour interval.')
optIfOChGroupSinkPrevDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 5, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChGroupSinkPrevDayEntry.setDescription('A conceptual row that contains OChGroup sink performance\n     monitoring information of an interface for the previous\n     24-hour interval.')
optIfOChGroupSinkPrevDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 5, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkPrevDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChGroupSinkPrevDayLastAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 5, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkPrevDayLastAggregatedInputPower.setDescription('The last aggregated optical power of all the DWDM input\n     channels in the OChGroup during the previous 24-hour interval.')
optIfOChGroupSinkPrevDayLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 5, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkPrevDayLowAggregatedInputPower.setDescription('The lowest aggregated optical power of all the DWDM input\n     channels in the OChGroup during the previous 24-hour interval.')
optIfOChGroupSinkPrevDayHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 5, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkPrevDayHighAggregatedInputPower.setDescription('The highest aggregated optical power of all the DWDM input\n     channels in the OChGroup during the previous 24-hour interval.')
optIfOChGroupSinkPrevDayLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 5, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkPrevDayLastOutputPower.setDescription('The last optical power monitored at the output\n     in the OChGroup during the previous 24-hour interval.')
optIfOChGroupSinkPrevDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 5, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkPrevDayLowOutputPower.setDescription('The lowest optical power monitored at the output\n     in the OChGroup during the previous 24-hour interval.')
optIfOChGroupSinkPrevDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 5, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSinkPrevDayHighOutputPower.setDescription('The highest optical power monitored at the output\n     in the OChGroup during the previous 24-hour interval.')
optIfOChGroupSrcCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6), )
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentTable.setDescription('A table of OChGroup source performance monitoring information for\n     the current 15-minute interval.')
optIfOChGroupSrcCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentEntry.setDescription('A conceptual row that contains OChGroup source performance\n     monitoring information of an interface for the current\n     15-minute interval.')
optIfOChGroupSrcCurrentSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChGroupSrcCurrentOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentOutputPower.setDescription('The optical power monitored at the output.')
optIfOChGroupSrcCurrentLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     current 15-minute interval.')
optIfOChGroupSrcCurrentHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     current 15-minute interval.')
optIfOChGroupSrcCurrentLowerOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentLowerOutputPowerThreshold.setDescription('The lower limit threshold on output power.  If\n     optIfOChGroupSrcCurrentOutputPower drops to this value or below,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOChGroupSrcCurrentUpperOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentUpperOutputPowerThreshold.setDescription('The upper limit threshold on output power.  If\n     optIfOChGroupSrcCurrentOutputPower reaches or exceeds this value,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOChGroupSrcCurrentAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentAggregatedInputPower.setDescription('The aggregated optical power monitored at the input.')
optIfOChGroupSrcCurrentLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentLowAggregatedInputPower.setDescription('The lowest aggregated optical power monitored at the input\n     during the current 15-minute interval.')
optIfOChGroupSrcCurrentHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 9), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentHighAggregatedInputPower.setDescription('The highest aggregated optical power monitored at the input\n     during the current 15-minute interval.')
optIfOChGroupSrcCurrentLowerInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 10), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentLowerInputPowerThreshold.setDescription('The lower limit threshold on input power.  If\n     optIfOChGroupSrcCurrentAggregatedInputPower drops to this value\n     or below, a Threshold Crossing Alert (TCA) should be sent.')
optIfOChGroupSrcCurrentUpperInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 6, 1, 11), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChGroupSrcCurrentUpperInputPowerThreshold.setDescription('The upper limit threshold on input power.  If\n     optIfOChGroupSrcCurrentAggregatedInputPower reaches or exceeds\n     this value, a Threshold Crossing Alert (TCA) should be sent.')
optIfOChGroupSrcIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 7), )
if mibBuilder.loadTexts: optIfOChGroupSrcIntervalTable.setDescription('A table of historical OChGroup source performance monitoring\n     information.')
optIfOChGroupSrcIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 7, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfOChGroupSrcIntervalNumber"))
if mibBuilder.loadTexts: optIfOChGroupSrcIntervalEntry.setDescription('A conceptual row that contains OChGroup source performance\n     monitoring information of an interface during a particular\n     historical interval.')
optIfOChGroupSrcIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 7, 1, 1), OptIfIntervalNumber())
if mibBuilder.loadTexts: optIfOChGroupSrcIntervalNumber.setDescription('Uniquely identifies the interval.')
optIfOChGroupSrcIntervalSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 7, 1, 2), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcIntervalSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChGroupSrcIntervalLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 7, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcIntervalLastOutputPower.setDescription('The last optical power monitored at the output during the\n     interval.')
optIfOChGroupSrcIntervalLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 7, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcIntervalLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     interval.')
optIfOChGroupSrcIntervalHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 7, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcIntervalHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     interval.')
optIfOChGroupSrcIntervalLastAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 7, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcIntervalLastAggregatedInputPower.setDescription('The last aggregated optical power monitored at the input\n     during the interval.')
optIfOChGroupSrcIntervalLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 7, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcIntervalLowAggregatedInputPower.setDescription('The lowest aggregated optical power monitored at the input\n     during the interval.')
optIfOChGroupSrcIntervalHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 7, 1, 8), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcIntervalHighAggregatedInputPower.setDescription('The highest aggregated optical power monitored at the input\n     during the interval.')
optIfOChGroupSrcCurDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 8), )
if mibBuilder.loadTexts: optIfOChGroupSrcCurDayTable.setDescription('A table of OChGroup source performance monitoring information for\n     the current 24-hour interval.')
optIfOChGroupSrcCurDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 8, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChGroupSrcCurDayEntry.setDescription('A conceptual row that contains OChGroup source performance\n     monitoring information of an interface for the current\n     24-hour interval.')
optIfOChGroupSrcCurDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 8, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChGroupSrcCurDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 8, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurDayLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     current 24-hour interval.')
optIfOChGroupSrcCurDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 8, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurDayHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     current 24-hour interval.')
optIfOChGroupSrcCurDayLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 8, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurDayLowAggregatedInputPower.setDescription('The lowest aggregated optical power monitored at the input\n     during the current 24-hour interval.')
optIfOChGroupSrcCurDayHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 8, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcCurDayHighAggregatedInputPower.setDescription('The highest aggregated optical power monitored at the input\n     during the current 24-hour interval.')
optIfOChGroupSrcPrevDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 9), )
if mibBuilder.loadTexts: optIfOChGroupSrcPrevDayTable.setDescription('A table of OChGroup source performance monitoring information for\n     the previous 24-hour interval.')
optIfOChGroupSrcPrevDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 9, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChGroupSrcPrevDayEntry.setDescription('A conceptual row that contains OChGroup source performance\n     monitoring information of an interface for the previous\n     24-hour interval.')
optIfOChGroupSrcPrevDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 9, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcPrevDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChGroupSrcPrevDayLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 9, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcPrevDayLastOutputPower.setDescription('The last optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOChGroupSrcPrevDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 9, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcPrevDayLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOChGroupSrcPrevDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 9, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcPrevDayHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOChGroupSrcPrevDayLastAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 9, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcPrevDayLastAggregatedInputPower.setDescription('The last aggregated optical power monitored at the input\n     during the previous 24-hour interval.')
optIfOChGroupSrcPrevDayLowAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 9, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcPrevDayLowAggregatedInputPower.setDescription('The lowest aggregated optical power monitored at the input\n     during the previous 24-hour interval.')
optIfOChGroupSrcPrevDayHighAggregatedInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 5, 9, 1, 7), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChGroupSrcPrevDayHighAggregatedInputPower.setDescription('The highest aggregated optical power monitored at the input\n     during the previous 24-hour interval.')
optIfOChConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 1), )
if mibBuilder.loadTexts: optIfOChConfigTable.setDescription('A table of OCh configuration information.')
optIfOChConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChConfigEntry.setDescription('A conceptual row that contains OCh configuration\n     information of an interface.')
optIfOChDirectionality = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 1, 1, 1), OptIfDirectionality()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChDirectionality.setDescription('Indicates the directionality of the entity.')
optIfOChCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 1, 1, 2), Bits().clone(namedValues=NamedValues(("losP", 0), ("los", 1), ("oci", 2), ("ssfP", 3), ("ssfO", 4), ("ssf", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChCurrentStatus.setDescription('Indicates the defect condition of the entity, if any.\n     This object is applicable when optIfOChDirectionality\n     has the value sink(1) or bidirectional(3).\n     In full-capability systems the bit position los(1) is not used.\n     In reduced-capability systems or at IrDI interfaces only\n     the bit positions los(1) and ssfP(3) are used.')
optIfOChSinkCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 2), )
if mibBuilder.loadTexts: optIfOChSinkCurrentTable.setDescription('A table of OCh sink performance monitoring information for\n     the current 15-minute interval.')
optIfOChSinkCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChSinkCurrentEntry.setDescription('A conceptual row that contains OCh sink performance\n     monitoring information for an interface for the current\n     15-minute interval.')
optIfOChSinkCurrentSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 2, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkCurrentSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChSinkCurrentInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 2, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkCurrentInputPower.setDescription('The optical power monitored at the input.')
optIfOChSinkCurrentLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 2, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkCurrentLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     current 15-minute interval.')
optIfOChSinkCurrentHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 2, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkCurrentHighInputPower.setDescription('The highest optical power monitored at the input during the\n     current 15-minute interval.')
optIfOChSinkCurrentLowerInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 2, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChSinkCurrentLowerInputPowerThreshold.setDescription('The lower limit threshold on input power.  If\n     optIfOChSinkCurrentInputPower drops to this value or below,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOChSinkCurrentUpperInputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 2, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChSinkCurrentUpperInputPowerThreshold.setDescription('The upper limit threshold on input power.  If\n     optIfOChSinkCurrentInputPower reaches or exceeds this value,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOChSinkIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 3), )
if mibBuilder.loadTexts: optIfOChSinkIntervalTable.setDescription('A table of historical OCh sink performance monitoring\n     information.')
optIfOChSinkIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfOChSinkIntervalNumber"))
if mibBuilder.loadTexts: optIfOChSinkIntervalEntry.setDescription('A conceptual row that contains OCh sink performance\n     monitoring information of an interface during a particular\n     historical interval.')
optIfOChSinkIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 3, 1, 1), OptIfIntervalNumber())
if mibBuilder.loadTexts: optIfOChSinkIntervalNumber.setDescription('Uniquely identifies the interval.')
optIfOChSinkIntervalSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 3, 1, 2), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkIntervalSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChSinkIntervalLastInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 3, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkIntervalLastInputPower.setDescription('The last optical power monitored at the input during the\n     interval.')
optIfOChSinkIntervalLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 3, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkIntervalLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     interval.')
optIfOChSinkIntervalHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 3, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkIntervalHighInputPower.setDescription('The highest optical power monitored at the input during the\n     interval.')
optIfOChSinkCurDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 4), )
if mibBuilder.loadTexts: optIfOChSinkCurDayTable.setDescription('A table of OCh sink performance monitoring information for\n     the current 24-hour interval.')
optIfOChSinkCurDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 4, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChSinkCurDayEntry.setDescription('A conceptual row that contains OCh sink performance\n     monitoring information of an interface for the current\n     24-hour interval.')
optIfOChSinkCurDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 4, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkCurDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChSinkCurDayLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 4, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkCurDayLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     current 24-hour interval.')
optIfOChSinkCurDayHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 4, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkCurDayHighInputPower.setDescription('The highest optical power monitored at the input during the\n     current 24-hour interval.')
optIfOChSinkPrevDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 5), )
if mibBuilder.loadTexts: optIfOChSinkPrevDayTable.setDescription('A table of OCh sink performance monitoring information for\n     the previous 24-hour interval.')
optIfOChSinkPrevDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 5, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChSinkPrevDayEntry.setDescription('A conceptual row that contains OCh sink performance\n     monitoring information of an interface for the previous\n     24-hour interval.')
optIfOChSinkPrevDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 5, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkPrevDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChSinkPrevDayLastInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 5, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkPrevDayLastInputPower.setDescription('The last optical power monitored at the input during the\n     previous 24-hour interval.')
optIfOChSinkPrevDayLowInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 5, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkPrevDayLowInputPower.setDescription('The lowest optical power monitored at the input during the\n     previous 24-hour interval.')
optIfOChSinkPrevDayHighInputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 5, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSinkPrevDayHighInputPower.setDescription('The highest optical power monitored at the input during the\n     previous 24-hour interval.')
optIfOChSrcCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 6), )
if mibBuilder.loadTexts: optIfOChSrcCurrentTable.setDescription('A table of OCh source performance monitoring information for\n     the current 15-minute interval.')
optIfOChSrcCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 6, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChSrcCurrentEntry.setDescription('A conceptual row that contains OCh source performance\n     monitoring information of an interface for the current\n     15-minute interval.')
optIfOChSrcCurrentSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 6, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcCurrentSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChSrcCurrentOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 6, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcCurrentOutputPower.setDescription('The optical power monitored at the output.')
optIfOChSrcCurrentLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 6, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcCurrentLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     current 15-minute interval.')
optIfOChSrcCurrentHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 6, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcCurrentHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     current 15-minute interval.')
optIfOChSrcCurrentLowerOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 6, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChSrcCurrentLowerOutputPowerThreshold.setDescription('The lower limit threshold on output power.  If\n     optIfOChSrcCurrentOutputPower drops to this value or below,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOChSrcCurrentUpperOutputPowerThreshold = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 6, 1, 6), Integer32()).setUnits('0.1 dbm').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOChSrcCurrentUpperOutputPowerThreshold.setDescription('The upper limit threshold on output power.  If\n     optIfOChSrcCurrentOutputPower reaches or exceeds this value,\n     a Threshold Crossing Alert (TCA) should be sent.')
optIfOChSrcIntervalTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 7), )
if mibBuilder.loadTexts: optIfOChSrcIntervalTable.setDescription('A table of historical OCh source performance monitoring\n     information.')
optIfOChSrcIntervalEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 7, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfOChSrcIntervalNumber"))
if mibBuilder.loadTexts: optIfOChSrcIntervalEntry.setDescription('A conceptual row that contains OCh source performance\n     monitoring information of an interface during a particular\n     historical interval.')
optIfOChSrcIntervalNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 7, 1, 1), OptIfIntervalNumber())
if mibBuilder.loadTexts: optIfOChSrcIntervalNumber.setDescription('Uniquely identifies the interval.')
optIfOChSrcIntervalSuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 7, 1, 2), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcIntervalSuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChSrcIntervalLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 7, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcIntervalLastOutputPower.setDescription('The last optical power monitored at the output during the\n     interval.')
optIfOChSrcIntervalLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 7, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcIntervalLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     interval.')
optIfOChSrcIntervalHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 7, 1, 5), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcIntervalHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     interval.')
optIfOChSrcCurDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 8), )
if mibBuilder.loadTexts: optIfOChSrcCurDayTable.setDescription('A table of OCh source performance monitoring information for\n     the current 24-hour interval.')
optIfOChSrcCurDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 8, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChSrcCurDayEntry.setDescription('A conceptual row that contains OCh source performance\n     monitoring information of an interface for the current\n     24-hour interval.')
optIfOChSrcCurDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 8, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcCurDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChSrcCurDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 8, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcCurDayLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n\n\n\n     current 24-hour interval.')
optIfOChSrcCurDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 8, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcCurDayHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     current 24-hour interval.')
optIfOChSrcPrevDayTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 9), )
if mibBuilder.loadTexts: optIfOChSrcPrevDayTable.setDescription('A table of OCh source performance monitoring information for\n     the previous 24-hour interval.')
optIfOChSrcPrevDayEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 9, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOChSrcPrevDayEntry.setDescription('A conceptual row that contains OCh source performance\n     monitoring information of an interface for the previous\n     24-hour interval.')
optIfOChSrcPrevDaySuspectedFlag = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 9, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcPrevDaySuspectedFlag.setDescription('If true, the data in this entry may be unreliable.')
optIfOChSrcPrevDayLastOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 9, 1, 2), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcPrevDayLastOutputPower.setDescription('The last optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOChSrcPrevDayLowOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 9, 1, 3), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcPrevDayLowOutputPower.setDescription('The lowest optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOChSrcPrevDayHighOutputPower = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 6, 9, 1, 4), Integer32()).setUnits('0.1 dbm').setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOChSrcPrevDayHighOutputPower.setDescription('The highest optical power monitored at the output during the\n     previous 24-hour interval.')
optIfOTUkConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1), )
if mibBuilder.loadTexts: optIfOTUkConfigTable.setDescription('A table of OTUk configuration information.')
optIfOTUkConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfOTUkConfigEntry.setDescription('A conceptual row that contains OTUk configuration\n     information of an interface.')
optIfOTUkDirectionality = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 1), OptIfDirectionality()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTUkDirectionality.setDescription('Indicates the directionality of the entity.')
optIfOTUkBitRateK = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 2), OptIfBitRateK()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTUkBitRateK.setDescription('Indicates the bit rate of the entity.')
optIfOTUkTraceIdentifierTransmitted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 3), OptIfTxTI()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTUkTraceIdentifierTransmitted.setDescription('The trace identifier transmitted.\n     This object is applicable when optIfOTUkDirectionality\n     has the value source(2) or bidirectional(3).  It must not\n     be instantiated in rows where optIfOTUkDirectionality\n     has the value sink(1).\n     If no value is ever set by a management entity for this\n     object, system-specific default value will be used.\n     Any implementation that instantiates this object must\n     document the system-specific default value or how it\n     is derived.')
optIfOTUkDAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 4), OptIfExDAPI()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTUkDAPIExpected.setDescription('The DAPI expected by the receiver.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfOTUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfOTUkDirectionality has the value source(2).\n     This object has no effect when optIfOTUkTIMDetMode has\n     the value off(1).')
optIfOTUkSAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 5), OptIfExSAPI()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTUkSAPIExpected.setDescription('The SAPI expected by the receiver.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfOTUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfOTUkDirectionality has the value source(2).\n     This object has no effect when optIfOTUkTIMDetMode has\n     the value off(1).')
optIfOTUkTraceIdentifierAccepted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 6), OptIfAcTI()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTUkTraceIdentifierAccepted.setDescription('The actual trace identifier accepted.\n     This object is only applicable to the sink function, i.e.,\n\n\n\n     only when optIfOTUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfOTUkDirectionality has the value source(2).\n     The value of this object is unspecified when\n     optIfOTUkCurrentStatus indicates a near-end defect\n     (i.e., ssf(3), lof(4), ais(5), lom(6)) that prevents\n     extraction of the trace message.')
optIfOTUkTIMDetMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 7), OptIfTIMDetMode()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTUkTIMDetMode.setDescription('Indicates the mode of the Trace Identifier Mismatch (TIM)\n     Detection function.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfOTUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfOTUkDirectionality has the value source(2).\n     The default value of this object is off(1).')
optIfOTUkTIMActEnabled = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 8), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTUkTIMActEnabled.setDescription('Indicates whether the Trace Identifier Mismatch (TIM)\n     Consequent Action function is enabled.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfOTUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfOTUkDirectionality has the value source(2).\n     This object has no effect when optIfOTUkTIMDetMode has\n     the value off(1).\n     The default value of this object is false(2).')
optIfOTUkDEGThr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 9), OptIfDEGThr()).setUnits('percentage').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTUkDEGThr.setDescription('Indicates the threshold level for declaring a performance\n     monitoring (PM) Second to be bad.  A PM Second is declared bad if\n     the percentage of detected errored blocks in that second is\n\n\n\n     greater than or equal to optIfOTUkDEGThr.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfOTUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfOTUkDirectionality has the value source(2).\n     The default value of this object is Severely Errored Second\n     (SES) Estimator (See ITU-T G.7710).')
optIfOTUkDEGM = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 10), OptIfDEGM()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTUkDEGM.setDescription('Indicates the threshold level for declaring a Degraded Signal\n     defect (dDEG).  A dDEG shall be declared if optIfOTUkDEGM\n     consecutive bad PM Seconds are detected.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfOTUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfOTUkDirectionality has the value source(2).\n     The default value of this object is 7 (See ITU-T G.7710).')
optIfOTUkSinkAdaptActive = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 11), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTUkSinkAdaptActive.setDescription('Indicates whether the sink adaptation function is activated or\n     not.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfOTUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfOTUkDirectionality has the value source(2).\n     The default value of this object is false(2).')
optIfOTUkSourceAdaptActive = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 12), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTUkSourceAdaptActive.setDescription('Indicates whether the source adaptation function is activated or\n     not.\n     This object is only applicable to the source function, i.e.,\n     only when optIfOTUkDirectionality has the value source(2)\n     or bidirectional(3).  It must not be instantiated in rows\n\n\n\n     where optIfOTUkDirectionality has the value sink(1).\n     The default value of this object is false(2).')
optIfOTUkSinkFECEnabled = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 13), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfOTUkSinkFECEnabled.setDescription('If Forward Error Correction (FEC) is supported, this object\n     indicates whether FEC at the OTUk sink adaptation function is\n     enabled or not.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfOTUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfOTUkDirectionality has the value source(2).\n     The default value of this object is true(1).')
optIfOTUkCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 1, 1, 14), Bits().clone(namedValues=NamedValues(("tim", 0), ("deg", 1), ("bdi", 2), ("ssf", 3), ("lof", 4), ("ais", 5), ("lom", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfOTUkCurrentStatus.setDescription('Indicates the defect condition of the entity, if any.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfOTUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfOTUkDirectionality has the value source(2).')
optIfGCC0ConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 2), )
if mibBuilder.loadTexts: optIfGCC0ConfigTable.setDescription('A table of GCC0 configuration information.')
optIfGCC0ConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfGCC0Directionality"))
if mibBuilder.loadTexts: optIfGCC0ConfigEntry.setDescription('A conceptual row that contains GCC0 configuration\n     information of an interface.  Each instance must\n     correspond to an instance of optIfOTUkConfigEntry.\n     Separate source and/or sink instances may exist\n     for a given ifIndex value, or a single bidirectional\n     instance may exist, but a bidirectional instance may\n     not coexist with a source or sink instance.\n     Instances of this conceptual row persist across\n     agent restarts.')
optIfGCC0Directionality = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 2, 1, 1), OptIfDirectionality())
if mibBuilder.loadTexts: optIfGCC0Directionality.setDescription('Indicates the directionality of the entity.\n     The values source(2) and bidirectional(3) are\n     not allowed if the corresponding instance of\n     optIfOTUkDirectionality has the value sink(1).\n     The values sink(1) and bidirectional(3) are\n     not allowed if the corresponding instance of\n     optIfOTUkDirectionality has the value source(2).')
optIfGCC0Application = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 2, 1, 2), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfGCC0Application.setDescription('Indicates the application transported by the GCC0 entity.\n     Example applications are ECC, User data channel.\n\n     The value of this object may not be changed when\n     optIfGCC0RowStatus has the value active(1).')
optIfGCC0RowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 7, 2, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfGCC0RowStatus.setDescription('This columnar object is used for creating and deleting a\n     conceptual row of the optIfGCC0 config table.\n     It is used to model the addGCC0Access and removeGCC0Access\n     operations of an OTUk_TTP for GCC0 access control as defined\n     in G.874.1.  Setting RowStatus to createAndGo or createAndWait\n     implies addGCC0Access.  Setting RowStatus to destroy implies\n     removeGCC0Access.')
optIfODUkConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 1), )
if mibBuilder.loadTexts: optIfODUkConfigTable.setDescription('A table of ODUk configuration information.')
optIfODUkConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfODUkConfigEntry.setDescription('A conceptual row that contains ODUk configuration\n     information of an interface.')
optIfODUkDirectionality = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 1, 1, 1), OptIfDirectionality()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkDirectionality.setDescription('Indicates the directionality of the entity.')
optIfODUkBitRateK = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 1, 1, 2), OptIfBitRateK()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkBitRateK.setDescription('Indicates the bit rate of the entity.')
optIfODUkTcmFieldsInUse = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 1, 1, 3), Bits().clone(namedValues=NamedValues(("tcmField1", 0), ("tcmField2", 1), ("tcmField3", 2), ("tcmField4", 3), ("tcmField5", 4), ("tcmField6", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkTcmFieldsInUse.setDescription('Indicates the TCM field(s) that are currently in use.\n     The positions of the bits correspond to the TCM fields.\n     A bit that is set to 1 means that the corresponding TCM\n     field is used.  This object will be updated when rows are\n     created in or deleted from the optIfODUkTConfigTable, or\n     the optIfODUkTNimConfigTable.')
optIfODUkPositionSeqCurrentSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 1, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkPositionSeqCurrentSize.setDescription('This variable indicates the current size of the position\n     sequence (i.e., number of TCM function and/or GCC12\n     access that have been created in the ODUk interface).\n     When the value of this variable is greater than zero,\n     it means that one or more TCM function and/or GCC12\n     access have been created in the ODUk interface.  In this\n     case, there will be as many rows in the\n\n\n\n     optIfODUkPositionSeqTable as the value of\n     optIfODUkPositionSeqCurrentSize  corresponding to this\n     ODUk interface, one row for each TCM function or GCC12\n     access.  The position of the TCM function and/or\n     GCC12 access within the sequence is indicated by the\n     optIfODUkPositionSeqPosition variable in\n     optIfODUkPositionSeqTable.\n     The optIfODUkPositionSeqTable also provides pointers\n     to the corresponding TCM function (optIfODUkT) and\n     GCC12 access (optIfGCC12) entities.')
optIfODUkTtpPresent = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 1, 1, 5), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkTtpPresent.setDescription('This object has the value true(1) if the ifEntry under which\n     it is instantiated contains an ODUk Trail Termination Point,\n     i.e., is the endpoint of an ODUk path.  In that case there\n     will be a corresponding row in the ODUk TTP config table and\n     it will not be possible to create corresponding rows in the\n     ODUk NIM config table.  This object has the value false(2)\n     if the ifEntry under which it is instantiated contains an\n     intermediate ODUk Connection Termination Point.  In that case\n     there is no corresponding row in the ODUk TTP config table,\n     but it will be possible to create corresponding rows in the\n     ODUk NIM config table.  This object also affects the allowable\n     options in rows created in the GCC12 config table and in the\n     ODUkT config table, as specified in the DESCRIPTION clauses\n     of the columns in those tables.')
optIfODUkTtpConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2), )
if mibBuilder.loadTexts: optIfODUkTtpConfigTable.setDescription('A table of ODUk TTP configuration information.')
optIfODUkTtpConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: optIfODUkTtpConfigEntry.setDescription('A conceptual row that contains ODUk TTP configuration\n     information of an interface.')
optIfODUkTtpTraceIdentifierTransmitted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2, 1, 1), OptIfTxTI()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfODUkTtpTraceIdentifierTransmitted.setDescription('The trace identifier transmitted.\n     This object is applicable when optIfODUkDirectionality\n     has the value source(2) or bidirectional(3).  It must not\n     be instantiated in rows where optIfODUkDirectionality\n     has the value sink(1).\n     If no value is ever set by a management entity for this\n     object, system-specific default value will be used.\n     Any implementation that instantiates this object must\n     document the system-specific default value or how it\n     is derived.')
optIfODUkTtpDAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2, 1, 2), OptIfExDAPI()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfODUkTtpDAPIExpected.setDescription('The DAPI expected by the receiver.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfODUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfODUkDirectionality has the value source(2).\n     This object has no effect when optIfODUkTtpTIMDetMode has\n     the value off(1).')
optIfODUkTtpSAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2, 1, 3), OptIfExSAPI()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfODUkTtpSAPIExpected.setDescription('The SAPI expected by the receiver.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfODUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfODUkDirectionality has the value source(2).\n     This object has no effect when optIfODUkTtpTIMDetMode has\n     the value off(1).')
optIfODUkTtpTraceIdentifierAccepted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2, 1, 4), OptIfAcTI()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkTtpTraceIdentifierAccepted.setDescription('The actual trace identifier accepted.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfODUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfODUkDirectionality has the value source(2).\n     The value of this object is unspecified when\n     optIfODUkTtpCurrentStatus indicates a near-end defect\n     (i.e., oci(0), lck(1), ssf(5)) that prevents extraction\n     of the trace message.')
optIfODUkTtpTIMDetMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2, 1, 5), OptIfTIMDetMode()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfODUkTtpTIMDetMode.setDescription('Indicates the mode of the Trace Identifier Mismatch (TIM)\n     Detection function.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfODUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfODUkDirectionality has the value source(2).\n     The default value of this object is off(1).')
optIfODUkTtpTIMActEnabled = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2, 1, 6), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfODUkTtpTIMActEnabled.setDescription('Indicates whether the Trace Identifier Mismatch (TIM)\n     Consequent Action function is enabled.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfODUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfODUkDirectionality has the value source(2).\n     This object has no effect when optIfODUkTtpTIMDetMode has\n     the value off(1).\n     The default value of this object is false(2).')
optIfODUkTtpDEGThr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2, 1, 7), OptIfDEGThr()).setUnits('percentage').setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfODUkTtpDEGThr.setDescription('Indicates the threshold level for declaring a performance\n     monitoring (PM) Second to be bad.  A PM Second is declared bad if\n     the percentage of detected errored blocks in that second is\n     greater than or equal to optIfODUkDEGThr.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfODUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfODUkDirectionality has the value source(2).\n     The default value of this object is Severely Errored Second\n     (SES) Estimator (See ITU-T G.7710).')
optIfODUkTtpDEGM = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2, 1, 8), OptIfDEGM()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: optIfODUkTtpDEGM.setDescription('Indicates the threshold level for declaring a Degraded Signal\n     defect (dDEG).  A dDEG shall be declared if optIfODUkDEGM\n     consecutive bad PM Seconds are detected.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfODUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfODUkDirectionality has the value source(2).\n     The default value of this object is 7 (See ITU-T G.7710).')
optIfODUkTtpCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 2, 1, 9), Bits().clone(namedValues=NamedValues(("oci", 0), ("lck", 1), ("tim", 2), ("deg", 3), ("bdi", 4), ("ssf", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkTtpCurrentStatus.setDescription('Indicates the defect condition of the entity, if any.\n     This object is only applicable to the sink function, i.e.,\n     only when optIfODUkDirectionality has the value sink(1)\n     or bidirectional(3).  It must not be instantiated in rows\n     where optIfODUkDirectionality has the value source(2).')
optIfODUkPositionSeqTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 3), )
if mibBuilder.loadTexts: optIfODUkPositionSeqTable.setDescription('A table of ODUk Position Sequence information.')
optIfODUkPositionSeqEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfODUkPositionSeqIndex"))
if mibBuilder.loadTexts: optIfODUkPositionSeqEntry.setDescription('A conceptual row that contains ODUk position sequence\n     information of an ODUk interface.  The ODUk interface\n     is identified by the ifIndex.  Associated with each\n     ODUk interface there may be one of more conceptual\n     rows in the optIfODUkPositionSeqTable.  Each row\n     represents a TCM or GCC12 access function within the\n     associated ODUk interface.  Rows of the\n     optIfODUkPositionSeqTable table are created/deleted\n     as the result of the creation/deletion of the optIfODUkT\n     or optIfGCC12 entities.')
optIfODUkPositionSeqIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 3, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: optIfODUkPositionSeqIndex.setDescription('This variable identifies a row in the\n     optIfODUkPositionSeqTable Table.\n     Each row of the optIfODUkPositionSeqTable Table\n     represents a TCM or GCC12 access function within the\n     associated ODUk interface.')
optIfODUkPositionSeqPosition = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 3, 1, 2), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkPositionSeqPosition.setDescription('This variable indicates the position of the TCM or\n     GCC12 access function within the sequence of TCMs &\n     GCC12 access functions of the associated ODUk\n     interface.  The TCM or GCC12 presented by this row is\n     referenced by the optIfODUkPositionSeqPointer variable.')
optIfODUkPositionSeqPointer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 3, 1, 3), RowPointer()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkPositionSeqPointer.setDescription('This variable identifies the TCM or GCC12 access function\n     by pointing to the corresponding optIfODUkT or optIfGCC12\n     entity.')
optIfODUkNimConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4), )
if mibBuilder.loadTexts: optIfODUkNimConfigTable.setDescription('A table of ODUkNim configuration information.')
optIfODUkNimConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfODUkNimDirectionality"))
if mibBuilder.loadTexts: optIfODUkNimConfigEntry.setDescription('A conceptual row that contains ODUkNim configuration\n     information of an interface.  Each instance must\n     correspond to an instance of optIfODUkConfigEntry\n     for which optIfODUkTtpPresent has the value false(2).\n\n     Instances of this conceptual row persist across\n     agent restarts, and read-create columns other\n     than the status column may be modified while the\n     row is active.')
optIfODUkNimDirectionality = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1, 1), OptIfSinkOrSource())
if mibBuilder.loadTexts: optIfODUkNimDirectionality.setDescription('Specifies the monitor point for the ODUk Path non-intrusive\n     monitoring function.  The value source(2) is not allowed\n     if the corresponding instance of optIfODUkDirectionality\n     has the value sink(1), and the value sink(1) is not allowed\n     if the corresponding instance of optIfODUkDirectionality\n     has the value source(2).  Either the value sink(1) or\n     source(2) is allowed if the corresponding instance of\n     optIfODUkDirectionality has the value bidirectional(3).\n\n     The value sink(1) means monitoring at the sink direction\n     path signal of the ODUk CTP.\n\n     The value source(2) means monitoring at the source direction\n\n\n\n     path signal of the ODUk CTP.  Monitoring the source direction\n     of an ODUk CTP is necessary in those cases where the ODUk CTP\n     is at an SNCP (Subnetwork Connection Protection) end (e.g., see\n     Figure I.1.2/G.874.1).  If one would like to get the performance\n     of the protected connection, one cannot use the NIM function\n     at both ODUk CTP sinks (before the matrix), instead one should\n     monitor the signal at the source ODUk CTP after the matrix.')
optIfODUkNimDAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1, 2), OptIfExDAPI()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkNimDAPIExpected.setDescription('The DAPI expected by the receiver.\n     This object has no effect if optIfODUkNimTIMDetMode has\n     the value off(1) or sapi(3).')
optIfODUkNimSAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1, 3), OptIfExSAPI()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkNimSAPIExpected.setDescription('The SAPI expected by the receiver.\n     This object has no effect if optIfODUkNimTIMDetMode has\n     the value off(1) or dapi(2).')
optIfODUkNimTraceIdentifierAccepted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1, 4), OptIfAcTI()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkNimTraceIdentifierAccepted.setDescription('The actual trace identifier accepted.  The value of\n     this object is unspecified if optIfODUkNimCurrentStatus\n     has any of the bit positions oci(0), lck(1), or ssf(5)\n     set or if optIfODUkNimRowStatus has any value other\n     than active(1).')
optIfODUkNimTIMDetMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1, 5), OptIfTIMDetMode()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkNimTIMDetMode.setDescription('Indicates the mode of the Trace Identifier Mismatch (TIM)\n     Detection function.')
optIfODUkNimTIMActEnabled = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1, 6), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkNimTIMActEnabled.setDescription('Indicates whether the Trace Identifier Mismatch (TIM)\n     Consequent Action function is enabled.')
optIfODUkNimDEGThr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1, 7), OptIfDEGThr()).setUnits('percentage').setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkNimDEGThr.setDescription('Indicates the threshold level for declaring a performance\n     monitoring (PM) Second to be bad.  A PM Second is declared bad\n     if the percentage of detected errored blocks in that second is\n     greater than or equal to optIfODUkNimDEGThr.')
optIfODUkNimDEGM = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1, 8), OptIfDEGM()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkNimDEGM.setDescription('Indicates the threshold level for declaring a Degraded Signal\n     defect (dDEG).  A dDEG shall be declared if optIfODUkNimDEGM\n     consecutive bad PM Seconds are detected.')
optIfODUkNimCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1, 9), Bits().clone(namedValues=NamedValues(("oci", 0), ("lck", 1), ("tim", 2), ("deg", 3), ("bdi", 4), ("ssf", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkNimCurrentStatus.setDescription('Indicates the defect condition of the entity, if\n     any.  The value of this object is unspecified if\n     optIfODUkNimRowStatus has any value other than\n\n\n\n     active(1).')
optIfODUkNimRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 4, 1, 10), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkNimRowStatus.setDescription('This columnar object is used for creating and deleting\n     a conceptual row of the optIfODUkNim config table.\n     It is used to model the activateNim and deactivateNim\n     operations of an OTUk_CTP for non-intrusive monitoring\n     control as defined in G.874.1.  Setting RowStatus to\n     createAndGo or createAndWait implies activateNim.\n     Setting RowStatus to destroy implies deactivateNim.')
optIfGCC12ConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 5), )
if mibBuilder.loadTexts: optIfGCC12ConfigTable.setDescription('A table of GCC12 configuration information.\n     The GCC function processes the GCC overhead bytes passing\n     through them but leave the remainder of the ODUk overhead\n     and payload data alone.')
optIfGCC12ConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 5, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfGCC12Codirectional"), (0, "OPT-IF-MIB", "optIfGCC12GCCAccess"))
if mibBuilder.loadTexts: optIfGCC12ConfigEntry.setDescription('A conceptual row that contains GCC12 configuration\n     information of an interface.  Each instance must\n     correspond to an instance of optIfODUkConfigEntry.\n     Separate instances providing GCC1-only access and\n     GCC2-only access may exist for a given ifIndex value,\n     or a single instance providing GCC1 + GCC2 may exist,\n     but a GCC1 + GCC2 instance may not coexist with a\n     GCC1-only or GCC2-only instance.\n\n     Instances of this conceptual row persist across agent\n     restarts.')
optIfGCC12Codirectional = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 5, 1, 1), TruthValue())
if mibBuilder.loadTexts: optIfGCC12Codirectional.setDescription('Indicates the directionality of the GCC12 termination with\n     respect to the associated ODUk CTP.  The value true(1) means\n     that the sink part of the GCC12 extracts COMMS data from the\n     signal at the input to the ODUk CTP sink and the source part\n     of the GCC12 inserts COMMS data into the signal at the output\n     of the ODUk CTP source.  The value false(2) means that the\n     sink part of the GCC12 extracts COMMS data from the signal at\n     the output of the ODUk CTP source and the source part of the\n     GCC12 inserts COMMS data into the signal at the input of the\n     ODUk CTP sink.  This attribute may assume either value when\n     the corresponding instance of optIfODUkTtpPresent has the\n     value false(2).  When the value of the corresponding instance\n     of optIfODUkTtpPresent is true(1) then the only value allowed\n     for this attribute is true(1).')
optIfGCC12GCCAccess = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 5, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("gcc1", 1), ("gcc2", 2), ("gcc1and2", 3),)))
if mibBuilder.loadTexts: optIfGCC12GCCAccess.setDescription('Indicates the GCC access represented by the entity.')
optIfGCC12GCCPassThrough = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 5, 1, 3), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfGCC12GCCPassThrough.setDescription('Controls whether the selected GCC overhead bytes are passed\n\n\n\n     through or modified.  The value true(1) means that the selected\n     GCC overhead bytes are passed through unmodified from the ODUk\n     CTP input to the ODUk CTP output.  The value false(2) means that\n     the selected GCC overhead bytes are set to zero at the ODUk CTP\n     output after the extraction of the COMMS data.  This object has\n     no effect if the corresponding instance of optIfODUkTtpPresent\n     has the value true(1).\n\n     The value of this object may not be changed when\n     optIfGCC12RowStatus has the value active(1).')
optIfGCC12Application = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 5, 1, 4), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfGCC12Application.setDescription('Indicates the application transported by the GCC12 entity.\n     Example applications are ECC, User data channel.\n\n     The value of this object may not be changed when\n     optIfGCC12RowStatus has the value active(1).')
optIfGCC12RowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 8, 5, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfGCC12RowStatus.setDescription('This columnar object is used for creating and deleting\n     a conceptual row of the optIfGCC12 config table.  It is\n     used to model the addGCC12Access and removeGCC12Access\n     operations of an ODUk_CTP or ODUk_TTP for GCC12 access\n     control as defined in G.874.1.  Setting RowStatus to\n     createAndGo or createAndWait implies addGCC12Access.\n     Setting RowStatus to destroy implies removeGCC12Access.\n     Successful addition/removal of the GCC12 access function\n     will result in updating the\n     optIfODUkPositionSeqCurrentSize variable and the\n     optIfODUkPositionSeqTable table of the associated\n     ODUk entry in the optIfODUkConfigTable.')
optIfODUkTConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1), )
if mibBuilder.loadTexts: optIfODUkTConfigTable.setDescription('A table of ODUkT configuration information.')
optIfODUkTConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfODUkTTcmField"), (0, "OPT-IF-MIB", "optIfODUkTCodirectional"))
if mibBuilder.loadTexts: optIfODUkTConfigEntry.setDescription('A conceptual row that contains ODUkT configuration\n     information of an interface.  Each instance must\n     correspond to an instance of optIfODUkConfigEntry.\n     Rows in this table are mutually exclusive with rows\n     in the ODUkT NIM config table -- in other words, this\n     row object may not be instantiated for a given pair\n     of ifIndex and TCM field values if a corresponding\n     instance of optIfODUkTNimConfigEntry already exists.\n\n     Instances of this conceptual row persist across agent\n     restarts.  Except where noted otherwise, read-create\n     columns other than the status column may be modified\n     while the row is active.')
optIfODUkTTcmField = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,6)))
if mibBuilder.loadTexts: optIfODUkTTcmField.setDescription('Indicates the tandem connection monitoring\n     field of the ODUk OH.  Valid values are\n     integers from 1 to 6.')
optIfODUkTCodirectional = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 2), TruthValue())
if mibBuilder.loadTexts: optIfODUkTCodirectional.setDescription('Indicates the directionality of the ODUkT termination point with\n     respect to the associated ODUk CTP.  The value true(1) means\n     that the sink part of the ODUkT TP extracts TCM data from the\n     signal at the input to the ODUk CTP sink and the source part\n     of the ODUkT TP inserts TCM data into the signal at the output\n     of the ODUk CTP source.  The value false(2) means that the\n     sink part of the ODUkT TP extracts TCM data from the signal at\n     the output of the ODUk CTP source and the source part of the\n     ODUkT TP inserts TCM data into the signal at the input of the\n     ODUk CTP sink.  This attribute may assume either value when\n     the corresponding instance of optIfODUkTtpPresent has the\n     value false(2).  When the value of the corresponding instance\n     of optIfODUkTtpPresent is true(1) then the only value allowed\n     for this attribute is true(1).')
optIfODUkTTraceIdentifierTransmitted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 3), OptIfTxTI()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTTraceIdentifierTransmitted.setDescription('The trace identifier transmitted.\n     This object is applicable only to the following three cases.\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value false(2), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value true(1).\n     It must not be instantiated in rows for all other cases.')
optIfODUkTDAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 4), OptIfExDAPI()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTDAPIExpected.setDescription('The DAPI expected by the receiver.\n     This object is applicable only to the following three cases.\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value true(1), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value false(2).\n     It must not be instantiated in rows for all other cases.\n     This object has no effect when optIfODUkTTIMDetMode has\n     the value off(1).')
optIfODUkTSAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 5), OptIfExSAPI()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTSAPIExpected.setDescription('The SAPI expected by the receiver.\n     This object is applicable only to the following three cases.\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value true(1), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value false(2).\n     It must not be instantiated in rows for all other cases.\n     This object has no effect when optIfODUkTTIMDetMode has\n     the value off(1).')
optIfODUkTTraceIdentifierAccepted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 6), OptIfAcTI()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkTTraceIdentifierAccepted.setDescription('The actual trace identifier accepted.\n     This object is applicable only to the following three cases.\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value true(1), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value false(2).\n     It must not be instantiated in rows for all other cases.\n     The value of this object is unspecified when\n     optIfODUkTCurrentStatus indicates a near-end defect\n     (i.e., oci(0), lck(1), ssf(5)) that prevents extraction\n\n\n\n     of the trace message.')
optIfODUkTTIMDetMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 7), OptIfTIMDetMode()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTTIMDetMode.setDescription('Indicates the mode of the Trace Identifier Mismatch (TIM)\n     Detection function.\n     This object is applicable only to the following three cases.\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value true(1), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value false(2).\n     It must not be instantiated in rows for all other cases.\n     The default value of this object is off(1).')
optIfODUkTTIMActEnabled = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 8), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTTIMActEnabled.setDescription('Indicates whether the Trace Identifier Mismatch (TIM)\n     Consequent Action function is enabled.\n     This object is applicable only to the following three cases.\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value true(1), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value false(2).\n     It must not be instantiated in rows for all other cases.\n     This object has no effect when optIfODUkTTIMDetMode has\n     the value off(1).\n     The default value of this object is false(2).')
optIfODUkTDEGThr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 9), OptIfDEGThr()).setUnits('percentage').setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTDEGThr.setDescription('Indicates the threshold level for declaring a performance\n     monitoring (PM) Second to be bad.  A PM Second is declared bad if\n     the percentage of detected errored blocks in that second is\n\n\n\n     greater than or equal to optIfODUkTDEGThr.\n     This object is applicable only to the following three cases.\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value true(1), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value false(2).\n     It must not be instantiated in rows for all other cases.\n     The default value of this object is Severely Errored Second\n     (SES) Estimator (See ITU-T G.7710).')
optIfODUkTDEGM = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 10), OptIfDEGM()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTDEGM.setDescription('Indicates the threshold level for declaring a Degraded Signal\n     defect (dDEG).  A dDEG shall be declared if optIfODUkTDEGM\n     consecutive bad PM Seconds are detected.\n     This object is applicable only to the following three cases.\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value true(1), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value false(2).\n     It must not be instantiated in rows for all other cases.\n     The default value of this object is 7 (See ITU-T G.7710).')
optIfODUkTSinkMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 11), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("operational", 1), ("monitor", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTSinkMode.setDescription('This variable specifies the TCM mode at the entity.\n     The value operational(1) means that TCM Overhead (TCMOH)\n     processes (see ITU-T G.798) shall be\n     performed and consequent actions for AIS, Trail\n     Signal Fail (TSF), Trail Signal Degraded (TSD) shall be\n     initiated in case of defects.\n     The value monitor(2) means that TCMOH processes shall be\n     performed but consequent actions for AIS, Trail\n     Server Failure (TSF), Trail Server Degraded (TSD) shall _not_ be\n     initiated in case of defects.\n\n\n\n     This object is applicable only when the value of\n     optIfODUkTtpPresent is false(2) and also either one of the\n     following three cases holds:\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value true(1), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value false(2).\n     It must not be instantiated in rows for all other cases.')
optIfODUkTSinkLockSignalAdminState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("locked", 1), ("normal", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTSinkLockSignalAdminState.setDescription('Provides the capability to provision the LOCK signal, which\n     is one of the ODUk maintenance signals, at the ODUKT sink.  When\n     a Tandem Connection endpoint is set to admin state locked,\n     it inserts the ODUk-LCK signal in the sink direction.\n\n     This object is applicable only when the value of\n     optIfODUkTtpPresent is false(2) and also either one of the\n     following three cases holds:\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value true(1), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value false(2).\n     It must not be instantiated in rows for all other cases.')
optIfODUkTSourceLockSignalAdminState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("locked", 1), ("normal", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTSourceLockSignalAdminState.setDescription('Provides the capability to provision the LOCK signal, which\n     is one of the ODUk maintenance signals, at the source.\n     When a Tandem Connection endpoint is set to admin state\n     locked, it inserts the ODUk-LCK signal in the source\n     direction.\n\n\n\n     This object is applicable only when either one of the\n     following three cases holds:\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value false(2), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value true(1).\n     It must not be instantiated in rows for all other cases.')
optIfODUkTCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 14), Bits().clone(namedValues=NamedValues(("oci", 0), ("lck", 1), ("tim", 2), ("deg", 3), ("bdi", 4), ("ssf", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkTCurrentStatus.setDescription('Indicates the defect condition of the entity, if any.\n     This object is applicable only when either one of the\n     following three cases holds:\n       (i) optIfODUkDirectionality has the value bidirectional(3), or\n       (ii) optIfODUkDirectionality has the value sink(1) and\n            optIfODUkTCodirectional has the value true(1), or\n       (iii) optIfODUkDirectionality has the value source(3) and\n             optIfODUkTCodirectional has the value false(2).\n     It must not be instantiated in rows for all other cases.')
optIfODUkTRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 1, 1, 15), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTRowStatus.setDescription('This columnar object is used for creating and deleting a\n     conceptual row of the optIfODUkT config table.\n     It is used to model the addTCM and removeTCM operations of an\n     ODUk_CTP or ODUk_TTP for Tandem connection monitoring as defined\n     in ITU-T G.874.1.\n     Setting RowStatus to createAndGo or createAndWait implies addTCM.\n     Setting RowStatus to destroy implies removeTCM.\n     Successful addition/removal of TCM will result in updating the\n     optIfODUkTcmFieldsInUse and optIfODUkPositionSeqCurrentSize\n     variables and the optIfODUkPositionSeqTable table of the\n\n\n\n     associated ODUk entry in the optIfODUkConfigTable.')
optIfODUkTNimConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2), )
if mibBuilder.loadTexts: optIfODUkTNimConfigTable.setDescription('A table of ODUkTNim configuration information.')
optIfODUkTNimConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "OPT-IF-MIB", "optIfODUkTNimTcmField"), (0, "OPT-IF-MIB", "optIfODUkTNimDirectionality"))
if mibBuilder.loadTexts: optIfODUkTNimConfigEntry.setDescription('A conceptual row that contains ODUkTNim configuration\n     information of an interface.  Each instance must\n     correspond to an instance of optIfODUkConfigEntry.\n     Rows in this table are mutually exclusive with rows\n     in the ODUkT config table -- in other words, this\n     row object may not be instantiated for a given pair\n     of ifIndex and TCM field values if a corresponding\n     instance of optIfODUkTConfigEntry already exists.\n\n     Instances of this conceptual row persist across\n     agent restarts, and read-create columns other\n     than the status column may be modified while the\n     row is active.')
optIfODUkTNimTcmField = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,6)))
if mibBuilder.loadTexts: optIfODUkTNimTcmField.setDescription('Indicates the tandem connection monitoring\n     field of the ODUk OH on which non-intrusive monitoring\n     is performed.  Valid values are\n     integers from 1 to 6.')
optIfODUkTNimDirectionality = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 2), OptIfSinkOrSource())
if mibBuilder.loadTexts: optIfODUkTNimDirectionality.setDescription('Specifies the monitor point for the ODUk TCM non-intrusive\n     monitoring function.  The value source(2) is not allowed\n     if the corresponding instance of optIfODUkDirectionality\n     has the value sink(1), and the value sink(1) is not allowed\n     if the corresponding instance of optIfODUkDirectionality\n     has the value source(2).  Either the value sink(1) or\n     source(2) is allowed if the corresponding instance of\n     optIfODUkDirectionality has the value bidirectional(3).\n     The value sink(1) means monitoring at the sink direction\n     TCM signal of the ODUk CTP.\n     The value source(2) means monitoring at the source direction\n     path signal of the ODUk CTP.')
optIfODUkTNimDAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 3), OptIfExDAPI()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTNimDAPIExpected.setDescription('The DAPI expected by the receiver.\n     This object has no effect if optIfODUkTNimTIMDetMode has\n     the value off(1) or sapi(3).')
optIfODUkTNimSAPIExpected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 4), OptIfExSAPI()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTNimSAPIExpected.setDescription('The SAPI expected by the receiver.\n     This object has no effect if optIfODUkTNimTIMDetMode has\n     the value off(1) or dapi(2).')
optIfODUkTNimTraceIdentifierAccepted = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 5), OptIfAcTI()).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkTNimTraceIdentifierAccepted.setDescription('The actual trace identifier accepted.  The value of\n     this object is unspecified if optIfODUkTNimCurrentStatus\n     has any of the bit positions oci(0), lck(1), or ssf(5)\n     set or if optIfODUkTNimRowStatus has any value other\n     than active(1).')
optIfODUkTNimTIMDetMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 6), OptIfTIMDetMode()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTNimTIMDetMode.setDescription('Indicates the mode of the Trace Identifier Mismatch (TIM)\n     Detection function.')
optIfODUkTNimTIMActEnabled = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 7), TruthValue()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTNimTIMActEnabled.setDescription('Indicates whether the Trace Identifier Mismatch (TIM)\n     Consequent Action function is enabled.')
optIfODUkTNimDEGThr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 8), OptIfDEGThr()).setUnits('percentage').setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTNimDEGThr.setDescription('Indicates the threshold level for declaring a performance\n     monitoring (PM) Second to be bad.  A PM Second is declared bad if\n     the percentage of detected errored blocks in that second is\n     greater than or equal to optIfODUkTNimDEGThr.')
optIfODUkTNimDEGM = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 9), OptIfDEGM()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTNimDEGM.setDescription('Indicates the threshold level for declaring a Degraded Signal\n     defect (dDEG).  A dDEG shall be declared if optIfODUkTNimDEGM\n     consecutive bad PM Seconds are detected.')
optIfODUkTNimCurrentStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 10), Bits().clone(namedValues=NamedValues(("oci", 0), ("lck", 1), ("tim", 2), ("deg", 3), ("bdi", 4), ("ssf", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: optIfODUkTNimCurrentStatus.setDescription('Indicates the defect condition of the entity, if any.\n     The value of this object is unspecified if\n     optIfODUkTNimRowStatus has any value other than\n     active(1).')
optIfODUkTNimRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 133, 1, 9, 2, 1, 11), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: optIfODUkTNimRowStatus.setDescription('This columnar object is used for creating and deleting a\n     conceptual row of the optIfODUkTNim config table.\n     It is used to model the addTCM and removeTCM operations of an\n     ODUk_CTP or ODUk_TTP for non-intrusive Tandem connection\n     monitoring as defined in ITU-T G.874.1.\n     Setting RowStatus to createAndGo or createAndWait implies addTCM.\n     Setting RowStatus to destroy implies removeTCM.\n     Successful addition/removal of Nim TCM will result in updating\n     the optIfODUkPositionSeqCurrentSize variable and the\n     optIfODUkPositionSeqTable table of the associated ODUk entry\n     in the optIfODUkConfigTable.')
optIfOTMnGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 1)).setObjects(*(("OPT-IF-MIB", "optIfOTMnOrder"), ("OPT-IF-MIB", "optIfOTMnReduced"), ("OPT-IF-MIB", "optIfOTMnBitRates"), ("OPT-IF-MIB", "optIfOTMnInterfaceType"), ("OPT-IF-MIB", "optIfOTMnTcmMax"), ("OPT-IF-MIB", "optIfOTMnOpticalReach"),))
if mibBuilder.loadTexts: optIfOTMnGroup.setDescription('A collection of OTMn structure information objects.')
optIfPerfMonGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 2)).setObjects(*(("OPT-IF-MIB", "optIfPerfMonCurrentTimeElapsed"), ("OPT-IF-MIB", "optIfPerfMonCurDayTimeElapsed"), ("OPT-IF-MIB", "optIfPerfMonIntervalNumIntervals"), ("OPT-IF-MIB", "optIfPerfMonIntervalNumInvalidIntervals"),))
if mibBuilder.loadTexts: optIfPerfMonGroup.setDescription('A collection of performance monitoring interval objects.')
optIfOTSnCommonGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 3)).setObjects(*(("OPT-IF-MIB", "optIfOTSnDirectionality"),))
if mibBuilder.loadTexts: optIfOTSnCommonGroup.setDescription('A collection of configuration objects\n     applicable to all OTSn interfaces.')
optIfOTSnSourceGroupFull = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 4)).setObjects(*(("OPT-IF-MIB", "optIfOTSnTraceIdentifierTransmitted"),))
if mibBuilder.loadTexts: optIfOTSnSourceGroupFull.setDescription('A collection of configuration objects\n     applicable to full-functionality/IaDI OTSn\n     interfaces that support source functions.')
optIfOTSnAPRStatusGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 5)).setObjects(*(("OPT-IF-MIB", "optIfOTSnAprStatus"),))
if mibBuilder.loadTexts: optIfOTSnAPRStatusGroup.setDescription('A collection of objects applicable to\n     OTSn interfaces that support Automatic\n     Power Reduction functions.')
optIfOTSnAPRControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 6)).setObjects(*(("OPT-IF-MIB", "optIfOTSnAprControl"),))
if mibBuilder.loadTexts: optIfOTSnAPRControlGroup.setDescription('A collection of objects applicable to\n     OTSn interfaces that provide Automatic\n     Power Reduction control functions.')
optIfOTSnSinkGroupBasic = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 7)).setObjects(*(("OPT-IF-MIB", "optIfOTSnCurrentStatus"),))
if mibBuilder.loadTexts: optIfOTSnSinkGroupBasic.setDescription('A collection of configuration objects\n     applicable to all OTSn interfaces that\n     support sink functions.')
optIfOTSnSinkGroupFull = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 8)).setObjects(*(("OPT-IF-MIB", "optIfOTSnDAPIExpected"), ("OPT-IF-MIB", "optIfOTSnSAPIExpected"), ("OPT-IF-MIB", "optIfOTSnTraceIdentifierAccepted"), ("OPT-IF-MIB", "optIfOTSnTIMDetMode"), ("OPT-IF-MIB", "optIfOTSnTIMActEnabled"),))
if mibBuilder.loadTexts: optIfOTSnSinkGroupFull.setDescription('A collection of configuration objects\n     applicable to full-functionality/IaDI OTSn\n     interfaces that support sink functions.')
optIfOTSnSinkPreOtnPMGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 9)).setObjects(*(("OPT-IF-MIB", "optIfOTSnSinkCurrentSuspectedFlag"), ("OPT-IF-MIB", "optIfOTSnSinkCurrentInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkCurrentLowInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkCurrentHighInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkCurrentOutputPower"), ("OPT-IF-MIB", "optIfOTSnSinkCurrentLowOutputPower"), ("OPT-IF-MIB", "optIfOTSnSinkCurrentHighOutputPower"), ("OPT-IF-MIB", "optIfOTSnSinkIntervalSuspectedFlag"), ("OPT-IF-MIB", "optIfOTSnSinkIntervalLastInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkIntervalLowInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkIntervalHighInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkIntervalLastOutputPower"), ("OPT-IF-MIB", "optIfOTSnSinkIntervalLowOutputPower"), ("OPT-IF-MIB", "optIfOTSnSinkIntervalHighOutputPower"), ("OPT-IF-MIB", "optIfOTSnSinkCurDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOTSnSinkCurDayLowInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkCurDayHighInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkCurDayLowOutputPower"), ("OPT-IF-MIB", "optIfOTSnSinkCurDayHighOutputPower"), ("OPT-IF-MIB", "optIfOTSnSinkPrevDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOTSnSinkPrevDayLastInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkPrevDayLowInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkPrevDayHighInputPower"), ("OPT-IF-MIB", "optIfOTSnSinkPrevDayLastOutputPower"), ("OPT-IF-MIB", "optIfOTSnSinkPrevDayLowOutputPower"), ("OPT-IF-MIB", "optIfOTSnSinkPrevDayHighOutputPower"),))
if mibBuilder.loadTexts: optIfOTSnSinkPreOtnPMGroup.setDescription('A collection of pre-OTN performance monitoring\n     objects applicable to OTSn interfaces that\n     support sink functions.')
optIfOTSnSinkPreOtnPMThresholdGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 10)).setObjects(*(("OPT-IF-MIB", "optIfOTSnSinkCurrentLowerInputPowerThreshold"), ("OPT-IF-MIB", "optIfOTSnSinkCurrentUpperInputPowerThreshold"), ("OPT-IF-MIB", "optIfOTSnSinkCurrentLowerOutputPowerThreshold"), ("OPT-IF-MIB", "optIfOTSnSinkCurrentUpperOutputPowerThreshold"),))
if mibBuilder.loadTexts: optIfOTSnSinkPreOtnPMThresholdGroup.setDescription('A collection of pre-OTN performance monitoring\n     threshold objects applicable to OTSn interfaces\n     that support sink functions.')
optIfOTSnSourcePreOtnPMGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 11)).setObjects(*(("OPT-IF-MIB", "optIfOTSnSrcCurrentSuspectedFlag"), ("OPT-IF-MIB", "optIfOTSnSrcCurrentOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcCurrentLowOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcCurrentHighOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcCurrentInputPower"), ("OPT-IF-MIB", "optIfOTSnSrcCurrentLowInputPower"), ("OPT-IF-MIB", "optIfOTSnSrcCurrentHighInputPower"), ("OPT-IF-MIB", "optIfOTSnSrcIntervalSuspectedFlag"), ("OPT-IF-MIB", "optIfOTSnSrcIntervalLastOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcIntervalLowOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcIntervalHighOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcIntervalLastInputPower"), ("OPT-IF-MIB", "optIfOTSnSrcIntervalLowInputPower"), ("OPT-IF-MIB", "optIfOTSnSrcIntervalHighInputPower"), ("OPT-IF-MIB", "optIfOTSnSrcCurDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOTSnSrcCurDayLowOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcCurDayHighOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcCurDayLowInputPower"), ("OPT-IF-MIB", "optIfOTSnSrcCurDayHighInputPower"), ("OPT-IF-MIB", "optIfOTSnSrcPrevDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOTSnSrcPrevDayLastOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcPrevDayLowOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcPrevDayHighOutputPower"), ("OPT-IF-MIB", "optIfOTSnSrcPrevDayLastInputPower"), ("OPT-IF-MIB", "optIfOTSnSrcPrevDayLowInputPower"), ("OPT-IF-MIB", "optIfOTSnSrcPrevDayHighInputPower"),))
if mibBuilder.loadTexts: optIfOTSnSourcePreOtnPMGroup.setDescription('A collection of pre-OTN performance monitoring\n     objects applicable to OTSn interfaces that\n     support source functions.')
optIfOTSnSourcePreOtnPMThresholdGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 12)).setObjects(*(("OPT-IF-MIB", "optIfOTSnSrcCurrentLowerOutputPowerThreshold"), ("OPT-IF-MIB", "optIfOTSnSrcCurrentUpperOutputPowerThreshold"), ("OPT-IF-MIB", "optIfOTSnSrcCurrentLowerInputPowerThreshold"), ("OPT-IF-MIB", "optIfOTSnSrcCurrentUpperInputPowerThreshold"),))
if mibBuilder.loadTexts: optIfOTSnSourcePreOtnPMThresholdGroup.setDescription('A collection of pre-OTN performance monitoring\n     threshold objects applicable to OTSn interfaces\n     that support source functions.')
optIfOMSnCommonGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 13)).setObjects(*(("OPT-IF-MIB", "optIfOMSnDirectionality"),))
if mibBuilder.loadTexts: optIfOMSnCommonGroup.setDescription('A collection of configuration objects\n     applicable to all OMSn interfaces.')
optIfOMSnSinkGroupBasic = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 14)).setObjects(*(("OPT-IF-MIB", "optIfOMSnCurrentStatus"),))
if mibBuilder.loadTexts: optIfOMSnSinkGroupBasic.setDescription('A collection of configuration objects\n     applicable to all OMSn interfaces that\n     support sink functions.')
optIfOMSnSinkPreOtnPMGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 15)).setObjects(*(("OPT-IF-MIB", "optIfOMSnSinkCurrentSuspectedFlag"), ("OPT-IF-MIB", "optIfOMSnSinkCurrentAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkCurrentLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkCurrentHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkCurrentOutputPower"), ("OPT-IF-MIB", "optIfOMSnSinkCurrentLowOutputPower"), ("OPT-IF-MIB", "optIfOMSnSinkCurrentHighOutputPower"), ("OPT-IF-MIB", "optIfOMSnSinkIntervalSuspectedFlag"), ("OPT-IF-MIB", "optIfOMSnSinkIntervalLastAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkIntervalLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkIntervalHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkIntervalLastOutputPower"), ("OPT-IF-MIB", "optIfOMSnSinkIntervalLowOutputPower"), ("OPT-IF-MIB", "optIfOMSnSinkIntervalHighOutputPower"), ("OPT-IF-MIB", "optIfOMSnSinkCurDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOMSnSinkCurDayLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkCurDayHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkCurDayLowOutputPower"), ("OPT-IF-MIB", "optIfOMSnSinkCurDayHighOutputPower"), ("OPT-IF-MIB", "optIfOMSnSinkPrevDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOMSnSinkPrevDayLastAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkPrevDayLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkPrevDayHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSinkPrevDayLastOutputPower"), ("OPT-IF-MIB", "optIfOMSnSinkPrevDayLowOutputPower"), ("OPT-IF-MIB", "optIfOMSnSinkPrevDayHighOutputPower"),))
if mibBuilder.loadTexts: optIfOMSnSinkPreOtnPMGroup.setDescription('A collection of pre-OTN performance monitoring\n     objects applicable to OMSn interfaces that\n     support sink functions.')
optIfOMSnSinkPreOtnPMThresholdGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 16)).setObjects(*(("OPT-IF-MIB", "optIfOMSnSinkCurrentLowerInputPowerThreshold"), ("OPT-IF-MIB", "optIfOMSnSinkCurrentUpperInputPowerThreshold"), ("OPT-IF-MIB", "optIfOMSnSinkCurrentLowerOutputPowerThreshold"), ("OPT-IF-MIB", "optIfOMSnSinkCurrentUpperOutputPowerThreshold"),))
if mibBuilder.loadTexts: optIfOMSnSinkPreOtnPMThresholdGroup.setDescription('A collection of pre-OTN performance monitoring\n     threshold objects applicable to OMSn interfaces\n     that support sink functions.')
optIfOMSnSourcePreOtnPMGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 17)).setObjects(*(("OPT-IF-MIB", "optIfOMSnSrcCurrentSuspectedFlag"), ("OPT-IF-MIB", "optIfOMSnSrcCurrentOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcCurrentLowOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcCurrentHighOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcCurrentAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSrcCurrentLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSrcCurrentHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSrcIntervalSuspectedFlag"), ("OPT-IF-MIB", "optIfOMSnSrcIntervalLastOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcIntervalLowOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcIntervalHighOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcIntervalLastAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSrcIntervalLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSrcIntervalHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSrcCurDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOMSnSrcCurDayLowOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcCurDayHighOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcCurDayLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSrcCurDayHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSrcPrevDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOMSnSrcPrevDayLastOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcPrevDayLowOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcPrevDayHighOutputPower"), ("OPT-IF-MIB", "optIfOMSnSrcPrevDayLastAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSrcPrevDayLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOMSnSrcPrevDayHighAggregatedInputPower"),))
if mibBuilder.loadTexts: optIfOMSnSourcePreOtnPMGroup.setDescription('A collection of pre-OTN performance monitoring\n     objects applicable to OMSn interfaces that\n     support source functions.')
optIfOMSnSourcePreOtnPMThresholdGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 18)).setObjects(*(("OPT-IF-MIB", "optIfOMSnSrcCurrentLowerOutputPowerThreshold"), ("OPT-IF-MIB", "optIfOMSnSrcCurrentUpperOutputPowerThreshold"), ("OPT-IF-MIB", "optIfOMSnSrcCurrentLowerInputPowerThreshold"), ("OPT-IF-MIB", "optIfOMSnSrcCurrentUpperInputPowerThreshold"),))
if mibBuilder.loadTexts: optIfOMSnSourcePreOtnPMThresholdGroup.setDescription('A collection of pre-OTN performance monitoring\n     threshold objects applicable to OMSn interfaces that\n     that support source functions.')
optIfOChGroupCommonGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 19)).setObjects(*(("OPT-IF-MIB", "optIfOChGroupDirectionality"),))
if mibBuilder.loadTexts: optIfOChGroupCommonGroup.setDescription('A collection of configuration objects\n     applicable to all OChGroup interfaces.')
optIfOChGroupSinkPreOtnPMGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 20)).setObjects(*(("OPT-IF-MIB", "optIfOChGroupSinkCurrentSuspectedFlag"), ("OPT-IF-MIB", "optIfOChGroupSinkCurrentAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkCurrentLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkCurrentHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkCurrentOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkCurrentLowOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkCurrentHighOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkIntervalSuspectedFlag"), ("OPT-IF-MIB", "optIfOChGroupSinkIntervalLastAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkIntervalLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkIntervalHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkIntervalLastOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkIntervalLowOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkIntervalHighOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkCurDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOChGroupSinkCurDayLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkCurDayHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkCurDayLowOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkCurDayHighOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkPrevDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOChGroupSinkPrevDayLastAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkPrevDayLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkPrevDayHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkPrevDayLastOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkPrevDayLowOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSinkPrevDayHighOutputPower"),))
if mibBuilder.loadTexts: optIfOChGroupSinkPreOtnPMGroup.setDescription('A collection of pre-OTN performance monitoring\n     objects applicable to OChGroup interfaces that\n     support sink functions.')
optIfOChGroupSinkPreOtnPMThresholdGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 21)).setObjects(*(("OPT-IF-MIB", "optIfOChGroupSinkCurrentLowerInputPowerThreshold"), ("OPT-IF-MIB", "optIfOChGroupSinkCurrentUpperInputPowerThreshold"), ("OPT-IF-MIB", "optIfOChGroupSinkCurrentLowerOutputPowerThreshold"), ("OPT-IF-MIB", "optIfOChGroupSinkCurrentUpperOutputPowerThreshold"),))
if mibBuilder.loadTexts: optIfOChGroupSinkPreOtnPMThresholdGroup.setDescription('A collection of pre-OTN performance monitoring\n     threshold objects applicable to OChGroup interfaces\n     that support sink functions.')
optIfOChGroupSourcePreOtnPMGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 22)).setObjects(*(("OPT-IF-MIB", "optIfOChGroupSrcCurrentSuspectedFlag"), ("OPT-IF-MIB", "optIfOChGroupSrcCurrentOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcCurrentLowOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcCurrentHighOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcCurrentAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcCurrentLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcCurrentHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcIntervalSuspectedFlag"), ("OPT-IF-MIB", "optIfOChGroupSrcIntervalLastOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcIntervalLowOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcIntervalHighOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcIntervalLastAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcIntervalLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcIntervalHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcCurDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOChGroupSrcCurDayLowOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcCurDayHighOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcCurDayLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcCurDayHighAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcPrevDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOChGroupSrcPrevDayLastOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcPrevDayLowOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcPrevDayHighOutputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcPrevDayLastAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcPrevDayLowAggregatedInputPower"), ("OPT-IF-MIB", "optIfOChGroupSrcPrevDayHighAggregatedInputPower"),))
if mibBuilder.loadTexts: optIfOChGroupSourcePreOtnPMGroup.setDescription('A collection of pre-OTN performance monitoring\n     objects applicable to OChGroup interfaces that\n     support source functions.')
optIfOChGroupSourcePreOtnPMThresholdGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 23)).setObjects(*(("OPT-IF-MIB", "optIfOChGroupSrcCurrentLowerOutputPowerThreshold"), ("OPT-IF-MIB", "optIfOChGroupSrcCurrentUpperOutputPowerThreshold"), ("OPT-IF-MIB", "optIfOChGroupSrcCurrentLowerInputPowerThreshold"), ("OPT-IF-MIB", "optIfOChGroupSrcCurrentUpperInputPowerThreshold"),))
if mibBuilder.loadTexts: optIfOChGroupSourcePreOtnPMThresholdGroup.setDescription('A collection of pre-OTN performance monitoring\n     threshold objects applicable to OChGroup interfaces that\n     that support source functions.')
optIfOChCommonGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 24)).setObjects(*(("OPT-IF-MIB", "optIfOChDirectionality"),))
if mibBuilder.loadTexts: optIfOChCommonGroup.setDescription('A collection of configuration objects\n     applicable to all OCh interfaces.')
optIfOChSinkGroupBasic = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 25)).setObjects(*(("OPT-IF-MIB", "optIfOChCurrentStatus"),))
if mibBuilder.loadTexts: optIfOChSinkGroupBasic.setDescription('A collection of configuration objects\n     applicable to all OCh interfaces that\n     support sink functions.')
optIfOChSinkPreOtnPMGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 26)).setObjects(*(("OPT-IF-MIB", "optIfOChSinkCurrentSuspectedFlag"), ("OPT-IF-MIB", "optIfOChSinkCurrentInputPower"), ("OPT-IF-MIB", "optIfOChSinkCurrentLowInputPower"), ("OPT-IF-MIB", "optIfOChSinkCurrentHighInputPower"), ("OPT-IF-MIB", "optIfOChSinkIntervalSuspectedFlag"), ("OPT-IF-MIB", "optIfOChSinkIntervalLastInputPower"), ("OPT-IF-MIB", "optIfOChSinkIntervalLowInputPower"), ("OPT-IF-MIB", "optIfOChSinkIntervalHighInputPower"), ("OPT-IF-MIB", "optIfOChSinkCurDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOChSinkCurDayLowInputPower"), ("OPT-IF-MIB", "optIfOChSinkCurDayHighInputPower"), ("OPT-IF-MIB", "optIfOChSinkPrevDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOChSinkPrevDayLastInputPower"), ("OPT-IF-MIB", "optIfOChSinkPrevDayLowInputPower"), ("OPT-IF-MIB", "optIfOChSinkPrevDayHighInputPower"),))
if mibBuilder.loadTexts: optIfOChSinkPreOtnPMGroup.setDescription('A collection of pre-OTN performance monitoring\n     objects applicable to OCh interfaces that\n     support sink functions.')
optIfOChSinkPreOtnPMThresholdGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 27)).setObjects(*(("OPT-IF-MIB", "optIfOChSinkCurrentLowerInputPowerThreshold"), ("OPT-IF-MIB", "optIfOChSinkCurrentUpperInputPowerThreshold"),))
if mibBuilder.loadTexts: optIfOChSinkPreOtnPMThresholdGroup.setDescription('A collection of pre-OTN performance monitoring\n     threshold objects applicable to OCh interfaces\n     that support sink functions.')
optIfOChSourcePreOtnPMGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 28)).setObjects(*(("OPT-IF-MIB", "optIfOChSrcCurrentSuspectedFlag"), ("OPT-IF-MIB", "optIfOChSrcCurrentOutputPower"), ("OPT-IF-MIB", "optIfOChSrcCurrentLowOutputPower"), ("OPT-IF-MIB", "optIfOChSrcCurrentHighOutputPower"), ("OPT-IF-MIB", "optIfOChSrcIntervalSuspectedFlag"), ("OPT-IF-MIB", "optIfOChSrcIntervalLastOutputPower"), ("OPT-IF-MIB", "optIfOChSrcIntervalLowOutputPower"), ("OPT-IF-MIB", "optIfOChSrcIntervalHighOutputPower"), ("OPT-IF-MIB", "optIfOChSrcCurDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOChSrcCurDayLowOutputPower"), ("OPT-IF-MIB", "optIfOChSrcCurDayHighOutputPower"), ("OPT-IF-MIB", "optIfOChSrcPrevDaySuspectedFlag"), ("OPT-IF-MIB", "optIfOChSrcPrevDayLastOutputPower"), ("OPT-IF-MIB", "optIfOChSrcPrevDayLowOutputPower"), ("OPT-IF-MIB", "optIfOChSrcPrevDayHighOutputPower"),))
if mibBuilder.loadTexts: optIfOChSourcePreOtnPMGroup.setDescription('A collection of pre-OTN performance monitoring\n     objects applicable to OCh interfaces that\n     support source functions.')
optIfOChSourcePreOtnPMThresholdGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 29)).setObjects(*(("OPT-IF-MIB", "optIfOChSrcCurrentLowerOutputPowerThreshold"), ("OPT-IF-MIB", "optIfOChSrcCurrentUpperOutputPowerThreshold"),))
if mibBuilder.loadTexts: optIfOChSourcePreOtnPMThresholdGroup.setDescription('A collection of pre-OTN performance monitoring\n     threshold objects applicable to OCh interfaces\n     that support source functions.')
optIfOTUkCommonGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 30)).setObjects(*(("OPT-IF-MIB", "optIfOTUkDirectionality"), ("OPT-IF-MIB", "optIfOTUkBitRateK"),))
if mibBuilder.loadTexts: optIfOTUkCommonGroup.setDescription('A collection of configuration objects\n     applicable to all OTUk interfaces.')
optIfOTUkSourceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 31)).setObjects(*(("OPT-IF-MIB", "optIfOTUkTraceIdentifierTransmitted"), ("OPT-IF-MIB", "optIfOTUkSourceAdaptActive"),))
if mibBuilder.loadTexts: optIfOTUkSourceGroup.setDescription('A collection of configuration objects\n     applicable to OTUk interfaces that\n     support source functions.')
optIfOTUkSinkGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 32)).setObjects(*(("OPT-IF-MIB", "optIfOTUkDAPIExpected"), ("OPT-IF-MIB", "optIfOTUkSAPIExpected"), ("OPT-IF-MIB", "optIfOTUkTraceIdentifierAccepted"), ("OPT-IF-MIB", "optIfOTUkTIMDetMode"), ("OPT-IF-MIB", "optIfOTUkTIMActEnabled"), ("OPT-IF-MIB", "optIfOTUkDEGThr"), ("OPT-IF-MIB", "optIfOTUkDEGM"), ("OPT-IF-MIB", "optIfOTUkSinkAdaptActive"), ("OPT-IF-MIB", "optIfOTUkSinkFECEnabled"), ("OPT-IF-MIB", "optIfOTUkCurrentStatus"),))
if mibBuilder.loadTexts: optIfOTUkSinkGroup.setDescription('A collection of configuration objects\n     applicable to OTUk interfaces that\n     support sink functions.')
optIfGCC0Group = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 33)).setObjects(*(("OPT-IF-MIB", "optIfGCC0Application"), ("OPT-IF-MIB", "optIfGCC0RowStatus"),))
if mibBuilder.loadTexts: optIfGCC0Group.setDescription('A collection of GCC0 configuration objects.')
optIfODUkGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 34)).setObjects(*(("OPT-IF-MIB", "optIfODUkDirectionality"), ("OPT-IF-MIB", "optIfODUkBitRateK"), ("OPT-IF-MIB", "optIfODUkTcmFieldsInUse"), ("OPT-IF-MIB", "optIfODUkPositionSeqCurrentSize"), ("OPT-IF-MIB", "optIfODUkPositionSeqPosition"), ("OPT-IF-MIB", "optIfODUkPositionSeqPointer"), ("OPT-IF-MIB", "optIfODUkTtpPresent"),))
if mibBuilder.loadTexts: optIfODUkGroup.setDescription('A collection of configuration objects\n     applicable to all ODUk interfaces.')
optIfODUkTtpSourceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 35)).setObjects(*(("OPT-IF-MIB", "optIfODUkTtpTraceIdentifierTransmitted"),))
if mibBuilder.loadTexts: optIfODUkTtpSourceGroup.setDescription('A collection of configuration objects\n     applicable to all interfaces that support\n     ODUk trail termination source functions.')
optIfODUkTtpSinkGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 36)).setObjects(*(("OPT-IF-MIB", "optIfODUkTtpDAPIExpected"), ("OPT-IF-MIB", "optIfODUkTtpSAPIExpected"), ("OPT-IF-MIB", "optIfODUkTtpTraceIdentifierAccepted"), ("OPT-IF-MIB", "optIfODUkTtpTIMDetMode"), ("OPT-IF-MIB", "optIfODUkTtpTIMActEnabled"), ("OPT-IF-MIB", "optIfODUkTtpDEGThr"), ("OPT-IF-MIB", "optIfODUkTtpDEGM"), ("OPT-IF-MIB", "optIfODUkTtpCurrentStatus"),))
if mibBuilder.loadTexts: optIfODUkTtpSinkGroup.setDescription('A collection of ODUk configuration objects\n     applicable to all interfaces that support\n     ODUk trail termination sink functions.')
optIfODUkNimGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 37)).setObjects(*(("OPT-IF-MIB", "optIfODUkNimDAPIExpected"), ("OPT-IF-MIB", "optIfODUkNimSAPIExpected"), ("OPT-IF-MIB", "optIfODUkNimTraceIdentifierAccepted"), ("OPT-IF-MIB", "optIfODUkNimTIMDetMode"), ("OPT-IF-MIB", "optIfODUkNimTIMActEnabled"), ("OPT-IF-MIB", "optIfODUkNimDEGThr"), ("OPT-IF-MIB", "optIfODUkNimDEGM"), ("OPT-IF-MIB", "optIfODUkNimCurrentStatus"), ("OPT-IF-MIB", "optIfODUkNimRowStatus"),))
if mibBuilder.loadTexts: optIfODUkNimGroup.setDescription('A collection of ODUk Nim configuration objects.')
optIfGCC12Group = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 38)).setObjects(*(("OPT-IF-MIB", "optIfGCC12GCCPassThrough"), ("OPT-IF-MIB", "optIfGCC12Application"), ("OPT-IF-MIB", "optIfGCC12RowStatus"),))
if mibBuilder.loadTexts: optIfGCC12Group.setDescription('A collection of GCC12 configuration objects.')
optIfODUkTCommonGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 39)).setObjects(*(("OPT-IF-MIB", "optIfODUkTRowStatus"),))
if mibBuilder.loadTexts: optIfODUkTCommonGroup.setDescription('A collection of configuration objects\n     applicable to all ODUkT instances.')
optIfODUkTSourceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 40)).setObjects(*(("OPT-IF-MIB", "optIfODUkTTraceIdentifierTransmitted"), ("OPT-IF-MIB", "optIfODUkTSourceLockSignalAdminState"),))
if mibBuilder.loadTexts: optIfODUkTSourceGroup.setDescription('A collection of configuration objects\n     applicable to all ODUkT instances\n     that provide source functions.')
optIfODUkTSinkGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 41)).setObjects(*(("OPT-IF-MIB", "optIfODUkTDAPIExpected"), ("OPT-IF-MIB", "optIfODUkTSAPIExpected"), ("OPT-IF-MIB", "optIfODUkTTraceIdentifierAccepted"), ("OPT-IF-MIB", "optIfODUkTTIMDetMode"), ("OPT-IF-MIB", "optIfODUkTTIMActEnabled"), ("OPT-IF-MIB", "optIfODUkTDEGThr"), ("OPT-IF-MIB", "optIfODUkTDEGM"), ("OPT-IF-MIB", "optIfODUkTCurrentStatus"),))
if mibBuilder.loadTexts: optIfODUkTSinkGroup.setDescription('A collection of configuration objects\n     applicable to all ODUkT instances\n     that provide sink functions.')
optIfODUkTSinkGroupCtp = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 42)).setObjects(*(("OPT-IF-MIB", "optIfODUkTSinkMode"), ("OPT-IF-MIB", "optIfODUkTSinkLockSignalAdminState"),))
if mibBuilder.loadTexts: optIfODUkTSinkGroupCtp.setDescription('A collection of configuration objects\n     applicable to ODUkT instances not\n     colocated with an ODUk TTP that\n     provide sink functions.')
optIfODUkTNimGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 133, 2, 1, 43)).setObjects(*(("OPT-IF-MIB", "optIfODUkTNimDAPIExpected"), ("OPT-IF-MIB", "optIfODUkTNimSAPIExpected"), ("OPT-IF-MIB", "optIfODUkTNimTraceIdentifierAccepted"), ("OPT-IF-MIB", "optIfODUkTNimTIMDetMode"), ("OPT-IF-MIB", "optIfODUkTNimTIMActEnabled"), ("OPT-IF-MIB", "optIfODUkTNimDEGThr"), ("OPT-IF-MIB", "optIfODUkTNimDEGM"), ("OPT-IF-MIB", "optIfODUkTNimCurrentStatus"), ("OPT-IF-MIB", "optIfODUkTNimRowStatus"),))
if mibBuilder.loadTexts: optIfODUkTNimGroup.setDescription('A collection of ODUkT Nim configuration objects.')
optIfOtnConfigCompl = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 133, 2, 2, 1)).setObjects(*(("OPT-IF-MIB", "optIfOTMnGroup"), ("OPT-IF-MIB", "optIfOTSnCommonGroup"), ("OPT-IF-MIB", "optIfOTSnSourceGroupFull"), ("OPT-IF-MIB", "optIfOTSnAPRStatusGroup"), ("OPT-IF-MIB", "optIfOTSnAPRControlGroup"), ("OPT-IF-MIB", "optIfOTSnSinkGroupBasic"), ("OPT-IF-MIB", "optIfOTSnSinkGroupFull"), ("OPT-IF-MIB", "optIfOMSnCommonGroup"), ("OPT-IF-MIB", "optIfOMSnSinkGroupBasic"), ("OPT-IF-MIB", "optIfOChGroupCommonGroup"), ("OPT-IF-MIB", "optIfOChCommonGroup"), ("OPT-IF-MIB", "optIfOChSinkGroupBasic"), ("OPT-IF-MIB", "optIfOTUkCommonGroup"), ("OPT-IF-MIB", "optIfOTUkSourceGroup"), ("OPT-IF-MIB", "optIfOTUkSinkGroup"), ("OPT-IF-MIB", "optIfGCC0Group"), ("OPT-IF-MIB", "optIfODUkGroup"), ("OPT-IF-MIB", "optIfODUkTtpSourceGroup"), ("OPT-IF-MIB", "optIfODUkTtpSinkGroup"), ("OPT-IF-MIB", "optIfODUkNimGroup"), ("OPT-IF-MIB", "optIfGCC12Group"), ("OPT-IF-MIB", "optIfODUkTCommonGroup"), ("OPT-IF-MIB", "optIfODUkTSourceGroup"), ("OPT-IF-MIB", "optIfODUkTSinkGroup"), ("OPT-IF-MIB", "optIfODUkTSinkGroupCtp"), ("OPT-IF-MIB", "optIfODUkTNimGroup"),))
if mibBuilder.loadTexts: optIfOtnConfigCompl.setDescription('Implementation requirements for the OTN configuration\n     functions defined in this MIB module.')
optIfPreOtnPMCompl = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 133, 2, 2, 2)).setObjects(*(("OPT-IF-MIB", "optIfPerfMonGroup"), ("OPT-IF-MIB", "optIfOTSnSinkPreOtnPMGroup"), ("OPT-IF-MIB", "optIfOTSnSinkPreOtnPMThresholdGroup"), ("OPT-IF-MIB", "optIfOTSnSourcePreOtnPMGroup"), ("OPT-IF-MIB", "optIfOTSnSourcePreOtnPMThresholdGroup"), ("OPT-IF-MIB", "optIfOMSnSinkPreOtnPMGroup"), ("OPT-IF-MIB", "optIfOMSnSinkPreOtnPMThresholdGroup"), ("OPT-IF-MIB", "optIfOMSnSourcePreOtnPMGroup"), ("OPT-IF-MIB", "optIfOMSnSourcePreOtnPMThresholdGroup"), ("OPT-IF-MIB", "optIfOChGroupSinkPreOtnPMGroup"), ("OPT-IF-MIB", "optIfOChGroupSinkPreOtnPMThresholdGroup"), ("OPT-IF-MIB", "optIfOChGroupSourcePreOtnPMGroup"), ("OPT-IF-MIB", "optIfOChGroupSourcePreOtnPMThresholdGroup"), ("OPT-IF-MIB", "optIfOChSinkPreOtnPMGroup"), ("OPT-IF-MIB", "optIfOChSinkPreOtnPMThresholdGroup"), ("OPT-IF-MIB", "optIfOChSourcePreOtnPMGroup"), ("OPT-IF-MIB", "optIfOChSourcePreOtnPMThresholdGroup"),))
if mibBuilder.loadTexts: optIfPreOtnPMCompl.setDescription('Implementation requirements for Pre-OTN performance\n     monitoring functions defined in this MIB module.')
mibBuilder.exportSymbols("OPT-IF-MIB", optIfOChGroupSourcePreOtnPMThresholdGroup=optIfOChGroupSourcePreOtnPMThresholdGroup, optIfOTSnSinkIntervalHighInputPower=optIfOTSnSinkIntervalHighInputPower, optIfOTMnGroup=optIfOTMnGroup, optIfOChGroupSinkCurrentLowerOutputPowerThreshold=optIfOChGroupSinkCurrentLowerOutputPowerThreshold, optIfGCC0RowStatus=optIfGCC0RowStatus, optIfODUkNimRowStatus=optIfODUkNimRowStatus, optIfODUkTTraceIdentifierAccepted=optIfODUkTTraceIdentifierAccepted, optIfODUkTTraceIdentifierTransmitted=optIfODUkTTraceIdentifierTransmitted, OptIfSinkOrSource=OptIfSinkOrSource, optIfODUkTtpDEGM=optIfODUkTtpDEGM, optIfOMSnSinkCurrentHighAggregatedInputPower=optIfOMSnSinkCurrentHighAggregatedInputPower, optIfOChGroupSrcCurrentUpperOutputPowerThreshold=optIfOChGroupSrcCurrentUpperOutputPowerThreshold, optIfOTSnSinkCurrentEntry=optIfOTSnSinkCurrentEntry, optIfOChGroupSrcPrevDayEntry=optIfOChGroupSrcPrevDayEntry, optIfOTSnSrcCurrentOutputPower=optIfOTSnSrcCurrentOutputPower, optIfOChGroupSinkCurrentLowAggregatedInputPower=optIfOChGroupSinkCurrentLowAggregatedInputPower, optIfODUkTtpTIMDetMode=optIfODUkTtpTIMDetMode, optIfGCC0ConfigTable=optIfGCC0ConfigTable, optIfODUkTDEGThr=optIfODUkTDEGThr, optIfOTSnSinkPreOtnPMThresholdGroup=optIfOTSnSinkPreOtnPMThresholdGroup, optIfOChGroupSinkIntervalHighAggregatedInputPower=optIfOChGroupSinkIntervalHighAggregatedInputPower, optIfOTSnSinkPrevDayHighInputPower=optIfOTSnSinkPrevDayHighInputPower, optIfOMSnSinkPrevDayLastAggregatedInputPower=optIfOMSnSinkPrevDayLastAggregatedInputPower, optIfOTSnSrcCurDayHighOutputPower=optIfOTSnSrcCurDayHighOutputPower, optIfOTSnSrcCurrentLowerOutputPowerThreshold=optIfOTSnSrcCurrentLowerOutputPowerThreshold, optIfOTMn=optIfOTMn, optIfOChGroupSrcIntervalSuspectedFlag=optIfOChGroupSrcIntervalSuspectedFlag, optIfOTSnSrcPrevDayLowOutputPower=optIfOTSnSrcPrevDayLowOutputPower, optIfODUkTSinkLockSignalAdminState=optIfODUkTSinkLockSignalAdminState, optIfGCC0ConfigEntry=optIfGCC0ConfigEntry, optIfOChGroupSrcIntervalEntry=optIfOChGroupSrcIntervalEntry, optIfODUkTNimDEGThr=optIfODUkTNimDEGThr, optIfOTSnSinkCurDayEntry=optIfOTSnSinkCurDayEntry, optIfODUkTNimCurrentStatus=optIfODUkTNimCurrentStatus, optIfOTSnSrcCurDayTable=optIfOTSnSrcCurDayTable, optIfOTMnInterfaceType=optIfOTMnInterfaceType, optIfOTSnSrcPrevDayEntry=optIfOTSnSrcPrevDayEntry, optIfODUkNimDirectionality=optIfODUkNimDirectionality, optIfOChSourcePreOtnPMThresholdGroup=optIfOChSourcePreOtnPMThresholdGroup, optIfODUkPositionSeqIndex=optIfODUkPositionSeqIndex, optIfOTSnSinkPrevDaySuspectedFlag=optIfOTSnSinkPrevDaySuspectedFlag, optIfODUkTSAPIExpected=optIfODUkTSAPIExpected, optIfGCC12GCCPassThrough=optIfGCC12GCCPassThrough, optIfGCC12RowStatus=optIfGCC12RowStatus, optIfOTUk=optIfOTUk, optIfOMSnSinkCurDaySuspectedFlag=optIfOMSnSinkCurDaySuspectedFlag, optIfOChGroupSinkCurrentSuspectedFlag=optIfOChGroupSinkCurrentSuspectedFlag, optIfODUkTtpConfigEntry=optIfODUkTtpConfigEntry, optIfOChSrcIntervalLowOutputPower=optIfOChSrcIntervalLowOutputPower, optIfOTSnSourcePreOtnPMThresholdGroup=optIfOTSnSourcePreOtnPMThresholdGroup, optIfODUkNimCurrentStatus=optIfODUkNimCurrentStatus, optIfOTSnSinkIntervalLowOutputPower=optIfOTSnSinkIntervalLowOutputPower, optIfOChGroupSrcCurrentLowerInputPowerThreshold=optIfOChGroupSrcCurrentLowerInputPowerThreshold, optIfOTSnSinkCurDaySuspectedFlag=optIfOTSnSinkCurDaySuspectedFlag, optIfOMSnSinkPrevDayLowOutputPower=optIfOMSnSinkPrevDayLowOutputPower, optIfOTSn=optIfOTSn, optIfODUkTNimConfigTable=optIfODUkTNimConfigTable, optIfOMSnSrcCurrentUpperOutputPowerThreshold=optIfOMSnSrcCurrentUpperOutputPowerThreshold, optIfOMSnSinkPreOtnPMThresholdGroup=optIfOMSnSinkPreOtnPMThresholdGroup, optIfODUkTCommonGroup=optIfODUkTCommonGroup, optIfOChGroupSinkIntervalLowAggregatedInputPower=optIfOChGroupSinkIntervalLowAggregatedInputPower, optIfOChGroupSinkIntervalLowOutputPower=optIfOChGroupSinkIntervalLowOutputPower, optIfConfs=optIfConfs, optIfOTSnAPRStatusGroup=optIfOTSnAPRStatusGroup, optIfODUkTSinkGroup=optIfODUkTSinkGroup, optIfOChGroupSrcPrevDayLowOutputPower=optIfOChGroupSrcPrevDayLowOutputPower, optIfOTUkDAPIExpected=optIfOTUkDAPIExpected, optIfOMSnSrcCurrentLowerOutputPowerThreshold=optIfOMSnSrcCurrentLowerOutputPowerThreshold, optIfOMSnSrcCurrentUpperInputPowerThreshold=optIfOMSnSrcCurrentUpperInputPowerThreshold, optIfOMSnSrcCurDayLowOutputPower=optIfOMSnSrcCurDayLowOutputPower, optIfODUkTSourceLockSignalAdminState=optIfODUkTSourceLockSignalAdminState, optIfOChGroupSinkCurDayEntry=optIfOChGroupSinkCurDayEntry, optIfOMSnSinkCurDayEntry=optIfOMSnSinkCurDayEntry, OptIfDirectionality=OptIfDirectionality, optIfOTSnAprControl=optIfOTSnAprControl, optIfOChSinkIntervalNumber=optIfOChSinkIntervalNumber, optIfOChSinkCurrentEntry=optIfOChSinkCurrentEntry, optIfODUkNimTraceIdentifierAccepted=optIfODUkNimTraceIdentifierAccepted, optIfGCC0Directionality=optIfGCC0Directionality, optIfOMSnSrcCurDayTable=optIfOMSnSrcCurDayTable, optIfOTSnSinkCurDayTable=optIfOTSnSinkCurDayTable, PYSNMP_MODULE_ID=optIfMibModule, optIfOMSnSinkPrevDayLastOutputPower=optIfOMSnSinkPrevDayLastOutputPower, optIfOMSnSrcIntervalNumber=optIfOMSnSrcIntervalNumber, optIfOChGroupSinkPrevDayHighOutputPower=optIfOChGroupSinkPrevDayHighOutputPower, optIfODUkPositionSeqPointer=optIfODUkPositionSeqPointer, OptIfTxTI=OptIfTxTI, optIfOChGroupSrcCurDayTable=optIfOChGroupSrcCurDayTable, optIfOMSnSrcIntervalEntry=optIfOMSnSrcIntervalEntry, optIfOChSrcPrevDayTable=optIfOChSrcPrevDayTable, optIfOTSnSourceGroupFull=optIfOTSnSourceGroupFull, optIfOChGroupSinkIntervalSuspectedFlag=optIfOChGroupSinkIntervalSuspectedFlag, optIfOTSnSinkCurDayLowOutputPower=optIfOTSnSinkCurDayLowOutputPower, optIfODUkPositionSeqTable=optIfODUkPositionSeqTable, optIfOTUkSinkGroup=optIfOTUkSinkGroup, optIfOChGroupSrcCurrentAggregatedInputPower=optIfOChGroupSrcCurrentAggregatedInputPower, optIfOTSnTIMActEnabled=optIfOTSnTIMActEnabled, optIfOChDirectionality=optIfOChDirectionality, optIfODUkTTIMDetMode=optIfODUkTTIMDetMode, optIfODUkTtpPresent=optIfODUkTtpPresent, optIfODUkTSourceGroup=optIfODUkTSourceGroup, optIfOChSrcPrevDayLastOutputPower=optIfOChSrcPrevDayLastOutputPower, optIfOChGroupSinkCurDayTable=optIfOChGroupSinkCurDayTable, optIfOChGroupSrcPrevDayTable=optIfOChGroupSrcPrevDayTable, optIfOMSnSrcCurrentHighAggregatedInputPower=optIfOMSnSrcCurrentHighAggregatedInputPower, optIfOTSnSinkCurrentLowerOutputPowerThreshold=optIfOTSnSinkCurrentLowerOutputPowerThreshold, optIfODUkTNimTraceIdentifierAccepted=optIfODUkTNimTraceIdentifierAccepted, optIfOChGroupSinkCurrentHighAggregatedInputPower=optIfOChGroupSinkCurrentHighAggregatedInputPower, optIfOChSrcCurDayEntry=optIfOChSrcCurDayEntry, optIfODUkTSinkMode=optIfODUkTSinkMode, optIfOChSrcIntervalSuspectedFlag=optIfOChSrcIntervalSuspectedFlag, optIfOTSnSrcCurrentLowerInputPowerThreshold=optIfOTSnSrcCurrentLowerInputPowerThreshold, optIfOCh=optIfOCh, optIfOChGroupSinkPrevDayLastOutputPower=optIfOChGroupSinkPrevDayLastOutputPower, optIfOChSinkPrevDayEntry=optIfOChSinkPrevDayEntry, optIfODUkTConfigEntry=optIfODUkTConfigEntry, optIfOChGroupSinkPrevDayLowOutputPower=optIfOChGroupSinkPrevDayLowOutputPower, optIfOChGroupDirectionality=optIfOChGroupDirectionality, optIfOTUkSourceGroup=optIfOTUkSourceGroup, optIfOChSinkCurrentUpperInputPowerThreshold=optIfOChSinkCurrentUpperInputPowerThreshold, optIfOMSnConfigTable=optIfOMSnConfigTable, optIfODUkNimConfigEntry=optIfODUkNimConfigEntry, optIfOMSnCommonGroup=optIfOMSnCommonGroup, optIfGCC0Application=optIfGCC0Application, optIfOTSnSrcCurrentHighOutputPower=optIfOTSnSrcCurrentHighOutputPower, optIfOMSnSinkCurrentLowerInputPowerThreshold=optIfOMSnSinkCurrentLowerInputPowerThreshold, optIfOTUkTIMActEnabled=optIfOTUkTIMActEnabled, optIfGCC12Codirectional=optIfGCC12Codirectional, optIfOTSnSinkCurrentHighInputPower=optIfOTSnSinkCurrentHighInputPower, optIfOChGroupSinkCurrentTable=optIfOChGroupSinkCurrentTable, optIfPerfMonIntervalNumIntervals=optIfPerfMonIntervalNumIntervals, optIfOChSrcCurrentSuspectedFlag=optIfOChSrcCurrentSuspectedFlag, optIfOChGroupSinkPreOtnPMThresholdGroup=optIfOChGroupSinkPreOtnPMThresholdGroup, optIfOTSnAPRControlGroup=optIfOTSnAPRControlGroup, optIfOTUkDirectionality=optIfOTUkDirectionality, optIfOChGroupSrcPrevDayHighAggregatedInputPower=optIfOChGroupSrcPrevDayHighAggregatedInputPower, optIfODUkTtpTraceIdentifierAccepted=optIfODUkTtpTraceIdentifierAccepted, optIfOChGroupSrcPrevDaySuspectedFlag=optIfOChGroupSrcPrevDaySuspectedFlag, OptIfAcTI=OptIfAcTI, optIfOChConfigTable=optIfOChConfigTable, optIfOTSnSinkCurrentTable=optIfOTSnSinkCurrentTable, optIfOTSnTraceIdentifierTransmitted=optIfOTSnTraceIdentifierTransmitted, optIfOTSnSinkPrevDayTable=optIfOTSnSinkPrevDayTable, optIfOChGroupSrcCurrentLowerOutputPowerThreshold=optIfOChGroupSrcCurrentLowerOutputPowerThreshold, optIfOMSnSinkCurDayLowAggregatedInputPower=optIfOMSnSinkCurDayLowAggregatedInputPower, optIfODUkNimDAPIExpected=optIfODUkNimDAPIExpected, optIfOChSrcPrevDayLowOutputPower=optIfOChSrcPrevDayLowOutputPower, optIfOChGroupSinkCurDayHighAggregatedInputPower=optIfOChGroupSinkCurDayHighAggregatedInputPower, optIfODUkTcmFieldsInUse=optIfODUkTcmFieldsInUse, OptIfBitRateK=OptIfBitRateK, optIfOChSrcIntervalHighOutputPower=optIfOChSrcIntervalHighOutputPower, optIfOTSnSinkCurDayHighInputPower=optIfOTSnSinkCurDayHighInputPower, optIfOTSnSrcCurrentLowInputPower=optIfOTSnSrcCurrentLowInputPower, optIfOChSinkPreOtnPMGroup=optIfOChSinkPreOtnPMGroup, optIfODUkTtpSAPIExpected=optIfODUkTtpSAPIExpected, optIfODUkNimConfigTable=optIfODUkNimConfigTable, optIfOTSnSinkPreOtnPMGroup=optIfOTSnSinkPreOtnPMGroup, optIfOTSnSrcPrevDayLowInputPower=optIfOTSnSrcPrevDayLowInputPower, optIfOTSnSrcCurDaySuspectedFlag=optIfOTSnSrcCurDaySuspectedFlag, optIfOMSnSrcCurDayLowAggregatedInputPower=optIfOMSnSrcCurDayLowAggregatedInputPower, optIfOTMnTcmMax=optIfOTMnTcmMax, optIfOMSnSrcCurrentSuspectedFlag=optIfOMSnSrcCurrentSuspectedFlag, optIfODUkConfigEntry=optIfODUkConfigEntry, optIfOChGroupSinkCurrentLowerInputPowerThreshold=optIfOChGroupSinkCurrentLowerInputPowerThreshold, optIfODUkTtpSourceGroup=optIfODUkTtpSourceGroup, optIfOChSrcCurrentEntry=optIfOChSrcCurrentEntry, optIfOMSnSinkCurrentOutputPower=optIfOMSnSinkCurrentOutputPower, optIfOChSinkCurDaySuspectedFlag=optIfOChSinkCurDaySuspectedFlag, optIfOChGroupSinkCurrentLowOutputPower=optIfOChGroupSinkCurrentLowOutputPower, optIfOMSnSinkIntervalSuspectedFlag=optIfOMSnSinkIntervalSuspectedFlag, optIfODUkTNimGroup=optIfODUkTNimGroup, optIfOTSnSrcIntervalLastInputPower=optIfOTSnSrcIntervalLastInputPower, optIfOTSnSinkIntervalHighOutputPower=optIfOTSnSinkIntervalHighOutputPower, optIfOMSnSrcPrevDayHighAggregatedInputPower=optIfOMSnSrcPrevDayHighAggregatedInputPower, optIfOTSnSinkCurrentLowInputPower=optIfOTSnSinkCurrentLowInputPower, optIfOTSnSrcCurDayLowOutputPower=optIfOTSnSrcCurDayLowOutputPower, optIfOMSnSrcIntervalSuspectedFlag=optIfOMSnSrcIntervalSuspectedFlag, optIfODUkTNimConfigEntry=optIfODUkTNimConfigEntry, optIfODUkTNimDEGM=optIfODUkTNimDEGM, optIfOChSinkPrevDayLastInputPower=optIfOChSinkPrevDayLastInputPower, optIfOTUkTraceIdentifierTransmitted=optIfOTUkTraceIdentifierTransmitted, optIfOChGroupSinkCurDayLowAggregatedInputPower=optIfOChGroupSinkCurDayLowAggregatedInputPower, optIfOChGroupSrcPrevDayHighOutputPower=optIfOChGroupSrcPrevDayHighOutputPower, optIfOChSinkIntervalHighInputPower=optIfOChSinkIntervalHighInputPower, optIfPreOtnPMCompl=optIfPreOtnPMCompl, optIfODUkTtpSinkGroup=optIfODUkTtpSinkGroup, optIfOMSnSinkPrevDayHighAggregatedInputPower=optIfOMSnSinkPrevDayHighAggregatedInputPower, optIfOMSnSourcePreOtnPMGroup=optIfOMSnSourcePreOtnPMGroup, optIfOChGroupSrcIntervalLastOutputPower=optIfOChGroupSrcIntervalLastOutputPower, optIfOChGroupSrcCurrentHighAggregatedInputPower=optIfOChGroupSrcCurrentHighAggregatedInputPower, optIfObjects=optIfObjects, optIfODUkTDAPIExpected=optIfODUkTDAPIExpected, optIfOMSnSrcIntervalLastAggregatedInputPower=optIfOMSnSrcIntervalLastAggregatedInputPower, optIfOChSrcCurDaySuspectedFlag=optIfOChSrcCurDaySuspectedFlag, optIfOTSnSrcIntervalSuspectedFlag=optIfOTSnSrcIntervalSuspectedFlag, optIfODUkTCodirectional=optIfODUkTCodirectional, optIfOChCurrentStatus=optIfOChCurrentStatus, optIfOTSnSinkCurrentLowOutputPower=optIfOTSnSinkCurrentLowOutputPower, optIfOTSnCommonGroup=optIfOTSnCommonGroup, optIfOTSnSinkCurrentUpperInputPowerThreshold=optIfOTSnSinkCurrentUpperInputPowerThreshold, optIfOChSinkPrevDayLowInputPower=optIfOChSinkPrevDayLowInputPower, optIfOChGroupSrcCurrentUpperInputPowerThreshold=optIfOChGroupSrcCurrentUpperInputPowerThreshold, optIfOChGroupSrcCurDayHighOutputPower=optIfOChGroupSrcCurDayHighOutputPower, optIfOMSnSinkPrevDayLowAggregatedInputPower=optIfOMSnSinkPrevDayLowAggregatedInputPower, optIfOTSnSinkCurrentHighOutputPower=optIfOTSnSinkCurrentHighOutputPower, optIfOMSnSinkIntervalLastAggregatedInputPower=optIfOMSnSinkIntervalLastAggregatedInputPower, optIfOChGroupSinkPrevDayTable=optIfOChGroupSinkPrevDayTable, optIfODUkNimTIMActEnabled=optIfODUkNimTIMActEnabled, optIfPerfMonGroup=optIfPerfMonGroup, optIfOTSnSinkPrevDayHighOutputPower=optIfOTSnSinkPrevDayHighOutputPower, optIfOMSnSinkCurDayTable=optIfOMSnSinkCurDayTable, OptIfTIMDetMode=OptIfTIMDetMode, optIfOTUkCurrentStatus=optIfOTUkCurrentStatus, optIfODUkTtpDEGThr=optIfODUkTtpDEGThr, optIfCompl=optIfCompl, optIfOChSinkPrevDayHighInputPower=optIfOChSinkPrevDayHighInputPower, optIfODUkTNimTIMDetMode=optIfODUkTNimTIMDetMode, optIfOTSnSinkPrevDayLowInputPower=optIfOTSnSinkPrevDayLowInputPower, optIfOChGroupSinkIntervalNumber=optIfOChGroupSinkIntervalNumber, optIfOChCommonGroup=optIfOChCommonGroup, optIfOChGroupSinkIntervalTable=optIfOChGroupSinkIntervalTable, optIfOMSnSrcIntervalTable=optIfOMSnSrcIntervalTable, optIfOChGroupSrcIntervalHighAggregatedInputPower=optIfOChGroupSrcIntervalHighAggregatedInputPower, optIfGCC12ConfigEntry=optIfGCC12ConfigEntry, optIfOChSrcCurrentOutputPower=optIfOChSrcCurrentOutputPower, optIfOMSnSrcCurrentLowAggregatedInputPower=optIfOMSnSrcCurrentLowAggregatedInputPower, optIfODUkNimGroup=optIfODUkNimGroup, optIfOChGroupSrcCurrentEntry=optIfOChGroupSrcCurrentEntry, optIfOTUkTIMDetMode=optIfOTUkTIMDetMode, optIfOTSnSrcCurrentLowOutputPower=optIfOTSnSrcCurrentLowOutputPower, optIfOChSrcCurDayHighOutputPower=optIfOChSrcCurDayHighOutputPower, optIfOTSnSinkCurDayLowInputPower=optIfOTSnSinkCurDayLowInputPower, optIfOChGroupSrcCurDayHighAggregatedInputPower=optIfOChGroupSrcCurDayHighAggregatedInputPower, optIfODUkConfigTable=optIfODUkConfigTable, optIfOChSrcIntervalLastOutputPower=optIfOChSrcIntervalLastOutputPower, optIfOTSnSrcCurrentUpperOutputPowerThreshold=optIfOTSnSrcCurrentUpperOutputPowerThreshold, optIfOChSrcCurDayLowOutputPower=optIfOChSrcCurDayLowOutputPower, optIfOMSnSinkIntervalHighOutputPower=optIfOMSnSinkIntervalHighOutputPower, optIfODUkGroup=optIfODUkGroup, optIfOChSinkCurrentSuspectedFlag=optIfOChSinkCurrentSuspectedFlag, optIfOMSnSrcPrevDayEntry=optIfOMSnSrcPrevDayEntry, optIfOChSrcCurrentLowerOutputPowerThreshold=optIfOChSrcCurrentLowerOutputPowerThreshold, optIfODUkNimDEGM=optIfODUkNimDEGM, optIfOChGroupSinkIntervalLastOutputPower=optIfOChGroupSinkIntervalLastOutputPower, optIfOMSnSinkCurrentLowAggregatedInputPower=optIfOMSnSinkCurrentLowAggregatedInputPower, optIfOTSnSinkIntervalTable=optIfOTSnSinkIntervalTable, optIfOChSrcIntervalEntry=optIfOChSrcIntervalEntry, optIfGCC0Group=optIfGCC0Group, optIfODUkTtpDAPIExpected=optIfODUkTtpDAPIExpected, optIfOMSnSrcIntervalLastOutputPower=optIfOMSnSrcIntervalLastOutputPower, optIfOChGroupSourcePreOtnPMGroup=optIfOChGroupSourcePreOtnPMGroup, optIfOMSnSinkCurrentLowerOutputPowerThreshold=optIfOMSnSinkCurrentLowerOutputPowerThreshold, optIfOChGroupSinkPrevDaySuspectedFlag=optIfOChGroupSinkPrevDaySuspectedFlag, optIfOMSnSinkIntervalTable=optIfOMSnSinkIntervalTable)
mibBuilder.exportSymbols("OPT-IF-MIB", optIfOMSnSrcCurrentOutputPower=optIfOMSnSrcCurrentOutputPower, optIfOMSnSrcCurrentLowOutputPower=optIfOMSnSrcCurrentLowOutputPower, optIfOChSrcPrevDayEntry=optIfOChSrcPrevDayEntry, optIfOTUkSourceAdaptActive=optIfOTUkSourceAdaptActive, optIfOTSnSinkPrevDayLastOutputPower=optIfOTSnSinkPrevDayLastOutputPower, optIfOChSinkIntervalTable=optIfOChSinkIntervalTable, optIfOTMnTable=optIfOTMnTable, optIfOChGroupSrcIntervalLastAggregatedInputPower=optIfOChGroupSrcIntervalLastAggregatedInputPower, optIfOTSnConfigEntry=optIfOTSnConfigEntry, optIfOMSnSrcPrevDayHighOutputPower=optIfOMSnSrcPrevDayHighOutputPower, optIfOChSinkIntervalLastInputPower=optIfOChSinkIntervalLastInputPower, optIfOMSnSinkGroupBasic=optIfOMSnSinkGroupBasic, optIfOTSnSinkPrevDayEntry=optIfOTSnSinkPrevDayEntry, optIfOMSnSrcCurDaySuspectedFlag=optIfOMSnSrcCurDaySuspectedFlag, optIfOChSrcIntervalTable=optIfOChSrcIntervalTable, optIfOChSinkCurDayEntry=optIfOChSinkCurDayEntry, optIfOChSinkCurrentHighInputPower=optIfOChSinkCurrentHighInputPower, optIfOTSnSrcIntervalEntry=optIfOTSnSrcIntervalEntry, optIfOChGroupSinkCurrentUpperInputPowerThreshold=optIfOChGroupSinkCurrentUpperInputPowerThreshold, optIfOChGroupSrcCurrentTable=optIfOChGroupSrcCurrentTable, optIfOTUkSinkFECEnabled=optIfOTUkSinkFECEnabled, optIfODUkTDEGM=optIfODUkTDEGM, optIfODUkTTIMActEnabled=optIfODUkTTIMActEnabled, optIfOMSnSrcIntervalLowOutputPower=optIfOMSnSrcIntervalLowOutputPower, optIfOChConfigEntry=optIfOChConfigEntry, optIfODUkNimDEGThr=optIfODUkNimDEGThr, optIfOChGroupSinkIntervalLastAggregatedInputPower=optIfOChGroupSinkIntervalLastAggregatedInputPower, optIfOChSrcCurrentUpperOutputPowerThreshold=optIfOChSrcCurrentUpperOutputPowerThreshold, optIfOTSnSrcPrevDayTable=optIfOTSnSrcPrevDayTable, optIfOChSrcIntervalNumber=optIfOChSrcIntervalNumber, optIfOTSnSrcCurrentEntry=optIfOTSnSrcCurrentEntry, optIfOTSnSrcCurrentUpperInputPowerThreshold=optIfOTSnSrcCurrentUpperInputPowerThreshold, optIfOChGroupSrcPrevDayLastOutputPower=optIfOChGroupSrcPrevDayLastOutputPower, optIfODUkTtpTraceIdentifierTransmitted=optIfODUkTtpTraceIdentifierTransmitted, optIfODUkNimTIMDetMode=optIfODUkNimTIMDetMode, optIfPerfMonCurDayTimeElapsed=optIfPerfMonCurDayTimeElapsed, optIfOTSnDAPIExpected=optIfOTSnDAPIExpected, optIfOTSnSrcIntervalHighInputPower=optIfOTSnSrcIntervalHighInputPower, optIfGCC12GCCAccess=optIfGCC12GCCAccess, optIfOMSnSourcePreOtnPMThresholdGroup=optIfOMSnSourcePreOtnPMThresholdGroup, optIfOMSnConfigEntry=optIfOMSnConfigEntry, optIfOChGroupSrcIntervalNumber=optIfOChGroupSrcIntervalNumber, optIfOTSnSinkGroupBasic=optIfOTSnSinkGroupBasic, optIfOChSinkPrevDayTable=optIfOChSinkPrevDayTable, optIfOChGroupSrcCurrentLowOutputPower=optIfOChGroupSrcCurrentLowOutputPower, optIfOMSnSinkPrevDayEntry=optIfOMSnSinkPrevDayEntry, optIfODUkTCurrentStatus=optIfODUkTCurrentStatus, optIfOChSinkIntervalEntry=optIfOChSinkIntervalEntry, optIfOMSnSinkPrevDaySuspectedFlag=optIfOMSnSinkPrevDaySuspectedFlag, optIfOTSnSrcCurrentTable=optIfOTSnSrcCurrentTable, optIfODUkTConfigTable=optIfODUkTConfigTable, optIfOTSnSinkCurrentOutputPower=optIfOTSnSinkCurrentOutputPower, optIfOTSnSinkCurrentSuspectedFlag=optIfOTSnSinkCurrentSuspectedFlag, optIfOMSnSrcPrevDayLastOutputPower=optIfOMSnSrcPrevDayLastOutputPower, optIfOTSnSAPIExpected=optIfOTSnSAPIExpected, optIfOMSnSinkIntervalLowAggregatedInputPower=optIfOMSnSinkIntervalLowAggregatedInputPower, optIfOTUkConfigEntry=optIfOTUkConfigEntry, optIfODUkPositionSeqPosition=optIfODUkPositionSeqPosition, optIfOTSnSrcCurDayEntry=optIfOTSnSrcCurDayEntry, optIfOTMnBitRates=optIfOTMnBitRates, optIfOChGroupSrcCurrentSuspectedFlag=optIfOChGroupSrcCurrentSuspectedFlag, optIfOChGroupCommonGroup=optIfOChGroupCommonGroup, optIfOChGroupSrcCurDayLowAggregatedInputPower=optIfOChGroupSrcCurDayLowAggregatedInputPower, optIfOChGroupSinkPrevDayHighAggregatedInputPower=optIfOChGroupSinkPrevDayHighAggregatedInputPower, optIfOChGroupSinkPreOtnPMGroup=optIfOChGroupSinkPreOtnPMGroup, OptIfIntervalNumber=OptIfIntervalNumber, optIfOChSinkIntervalLowInputPower=optIfOChSinkIntervalLowInputPower, optIfOTSnSinkIntervalLastOutputPower=optIfOTSnSinkIntervalLastOutputPower, optIfMibModule=optIfMibModule, optIfOChGroupSinkPrevDayLastAggregatedInputPower=optIfOChGroupSinkPrevDayLastAggregatedInputPower, optIfOChSinkCurrentInputPower=optIfOChSinkCurrentInputPower, optIfOMSnSinkCurrentEntry=optIfOMSnSinkCurrentEntry, optIfPerfMonIntervalTable=optIfPerfMonIntervalTable, optIfOTSnSinkIntervalEntry=optIfOTSnSinkIntervalEntry, optIfOMSnSrcCurrentLowerInputPowerThreshold=optIfOMSnSrcCurrentLowerInputPowerThreshold, optIfOTSnSinkIntervalSuspectedFlag=optIfOTSnSinkIntervalSuspectedFlag, optIfOTMnOrder=optIfOTMnOrder, optIfOChSrcCurrentTable=optIfOChSrcCurrentTable, optIfOTSnCurrentStatus=optIfOTSnCurrentStatus, optIfODUkTNimRowStatus=optIfODUkTNimRowStatus, optIfOTSnSinkCurrentLowerInputPowerThreshold=optIfOTSnSinkCurrentLowerInputPowerThreshold, OptIfDEGThr=OptIfDEGThr, optIfOMSnSinkCurDayHighAggregatedInputPower=optIfOMSnSinkCurDayHighAggregatedInputPower, optIfOChGroupSrcCurDayLowOutputPower=optIfOChGroupSrcCurDayLowOutputPower, optIfOTSnSrcCurrentInputPower=optIfOTSnSrcCurrentInputPower, optIfOChGroupSinkPrevDayEntry=optIfOChGroupSinkPrevDayEntry, optIfOTSnSrcIntervalNumber=optIfOTSnSrcIntervalNumber, optIfODUkDirectionality=optIfODUkDirectionality, optIfOMSnSinkPreOtnPMGroup=optIfOMSnSinkPreOtnPMGroup, optIfOChSrcCurrentHighOutputPower=optIfOChSrcCurrentHighOutputPower, optIfOChGroupSinkCurrentEntry=optIfOChGroupSinkCurrentEntry, optIfPerfMonIntervalEntry=optIfPerfMonIntervalEntry, optIfOChGroupSinkCurDaySuspectedFlag=optIfOChGroupSinkCurDaySuspectedFlag, optIfOMSnSinkPrevDayHighOutputPower=optIfOMSnSinkPrevDayHighOutputPower, optIfOMSnSrcPrevDayTable=optIfOMSnSrcPrevDayTable, optIfOChGroupSinkCurrentUpperOutputPowerThreshold=optIfOChGroupSinkCurrentUpperOutputPowerThreshold, optIfOMSnSrcPrevDayLowAggregatedInputPower=optIfOMSnSrcPrevDayLowAggregatedInputPower, optIfOMSnSrcPrevDaySuspectedFlag=optIfOMSnSrcPrevDaySuspectedFlag, optIfOChGroupSrcPrevDayLastAggregatedInputPower=optIfOChGroupSrcPrevDayLastAggregatedInputPower, optIfODUkTNimDAPIExpected=optIfODUkTNimDAPIExpected, optIfOTSnSinkIntervalLowInputPower=optIfOTSnSinkIntervalLowInputPower, optIfOMSnSinkCurrentHighOutputPower=optIfOMSnSinkCurrentHighOutputPower, optIfOChGroupSinkCurDayHighOutputPower=optIfOChGroupSinkCurDayHighOutputPower, optIfOTUkBitRateK=optIfOTUkBitRateK, optIfOChGroupSinkIntervalEntry=optIfOChGroupSinkIntervalEntry, optIfOTSnDirectionality=optIfOTSnDirectionality, optIfODUkTNimSAPIExpected=optIfODUkTNimSAPIExpected, optIfOMSnSinkIntervalLastOutputPower=optIfOMSnSinkIntervalLastOutputPower, optIfOTSnSrcCurDayLowInputPower=optIfOTSnSrcCurDayLowInputPower, optIfOTSnSinkCurDayHighOutputPower=optIfOTSnSinkCurDayHighOutputPower, optIfOMSnSinkCurrentAggregatedInputPower=optIfOMSnSinkCurrentAggregatedInputPower, optIfODUkT=optIfODUkT, optIfOChGroupSrcIntervalLowOutputPower=optIfOChGroupSrcIntervalLowOutputPower, optIfODUkPositionSeqEntry=optIfODUkPositionSeqEntry, optIfOMSnSinkCurrentUpperOutputPowerThreshold=optIfOMSnSinkCurrentUpperOutputPowerThreshold, optIfOChSinkPrevDaySuspectedFlag=optIfOChSinkPrevDaySuspectedFlag, optIfOChGroupSrcIntervalLowAggregatedInputPower=optIfOChGroupSrcIntervalLowAggregatedInputPower, optIfOMSnCurrentStatus=optIfOMSnCurrentStatus, optIfOTSnSinkIntervalNumber=optIfOTSnSinkIntervalNumber, optIfOMSnSinkCurDayLowOutputPower=optIfOMSnSinkCurDayLowOutputPower, optIfODUkTNimDirectionality=optIfODUkTNimDirectionality, optIfOTSnSrcCurDayHighInputPower=optIfOTSnSrcCurDayHighInputPower, optIfOChSinkCurDayLowInputPower=optIfOChSinkCurDayLowInputPower, optIfODUkTTcmField=optIfODUkTTcmField, optIfOChSourcePreOtnPMGroup=optIfOChSourcePreOtnPMGroup, optIfOTSnSrcPrevDayLastOutputPower=optIfOTSnSrcPrevDayLastOutputPower, optIfPerfMonIntervalNumInvalidIntervals=optIfPerfMonIntervalNumInvalidIntervals, optIfOMSnSinkCurrentTable=optIfOMSnSinkCurrentTable, optIfOTMnOpticalReach=optIfOTMnOpticalReach, optIfOTSnSinkPrevDayLowOutputPower=optIfOTSnSinkPrevDayLowOutputPower, optIfODUkTtpConfigTable=optIfODUkTtpConfigTable, optIfOChSinkIntervalSuspectedFlag=optIfOChSinkIntervalSuspectedFlag, optIfOTSnSrcIntervalLowOutputPower=optIfOTSnSrcIntervalLowOutputPower, optIfODUkPositionSeqCurrentSize=optIfODUkPositionSeqCurrentSize, optIfOMSnSrcCurDayHighOutputPower=optIfOMSnSrcCurDayHighOutputPower, optIfOMSnSinkCurrentLowOutputPower=optIfOMSnSinkCurrentLowOutputPower, optIfODUkTNimTIMActEnabled=optIfODUkTNimTIMActEnabled, optIfOTSnTraceIdentifierAccepted=optIfOTSnTraceIdentifierAccepted, optIfOMSn=optIfOMSn, optIfODUkTRowStatus=optIfODUkTRowStatus, optIfOTUkTraceIdentifierAccepted=optIfOTUkTraceIdentifierAccepted, optIfOChGroupConfigEntry=optIfOChGroupConfigEntry, optIfOMSnSrcCurrentEntry=optIfOMSnSrcCurrentEntry, optIfOChSrcPrevDayHighOutputPower=optIfOChSrcPrevDayHighOutputPower, OptIfDEGM=OptIfDEGM, optIfOTSnSinkCurrentInputPower=optIfOTSnSinkCurrentInputPower, optIfOChSinkCurrentTable=optIfOChSinkCurrentTable, optIfGCC12ConfigTable=optIfGCC12ConfigTable, optIfOChGroupSinkPrevDayLowAggregatedInputPower=optIfOChGroupSinkPrevDayLowAggregatedInputPower, optIfOChGroupSrcCurDayEntry=optIfOChGroupSrcCurDayEntry, optIfPerfMonCurrentTimeElapsed=optIfPerfMonCurrentTimeElapsed, optIfOMSnSrcIntervalHighAggregatedInputPower=optIfOMSnSrcIntervalHighAggregatedInputPower, optIfOChSinkCurrentLowerInputPowerThreshold=optIfOChSinkCurrentLowerInputPowerThreshold, optIfOTUkDEGThr=optIfOTUkDEGThr, optIfODUkTtpTIMActEnabled=optIfODUkTtpTIMActEnabled, optIfOTMnEntry=optIfOTMnEntry, optIfOMSnSrcCurDayHighAggregatedInputPower=optIfOMSnSrcCurDayHighAggregatedInputPower, optIfOChGroupSrcCurrentOutputPower=optIfOChGroupSrcCurrentOutputPower, optIfOTSnSrcIntervalLowInputPower=optIfOTSnSrcIntervalLowInputPower, optIfOTUkCommonGroup=optIfOTUkCommonGroup, optIfOChGroupSrcCurrentLowAggregatedInputPower=optIfOChGroupSrcCurrentLowAggregatedInputPower, optIfOTSnSinkPrevDayLastInputPower=optIfOTSnSinkPrevDayLastInputPower, optIfOMSnSinkIntervalEntry=optIfOMSnSinkIntervalEntry, optIfOTSnSinkCurrentUpperOutputPowerThreshold=optIfOTSnSinkCurrentUpperOutputPowerThreshold, optIfOChGroupSrcPrevDayLowAggregatedInputPower=optIfOChGroupSrcPrevDayLowAggregatedInputPower, optIfOChSinkCurDayTable=optIfOChSinkCurDayTable, optIfOChSrcCurDayTable=optIfOChSrcCurDayTable, optIfOMSnSinkIntervalHighAggregatedInputPower=optIfOMSnSinkIntervalHighAggregatedInputPower, optIfOChSinkCurrentLowInputPower=optIfOChSinkCurrentLowInputPower, optIfGCC12Application=optIfGCC12Application, OptIfExSAPI=OptIfExSAPI, optIfOMSnSinkPrevDayTable=optIfOMSnSinkPrevDayTable, optIfOChGroupSrcIntervalTable=optIfOChGroupSrcIntervalTable, optIfODUkTtpCurrentStatus=optIfODUkTtpCurrentStatus, optIfOMSnSrcCurrentAggregatedInputPower=optIfOMSnSrcCurrentAggregatedInputPower, optIfOTSnSinkIntervalLastInputPower=optIfOTSnSinkIntervalLastInputPower, optIfOChSinkGroupBasic=optIfOChSinkGroupBasic, optIfOTSnSrcCurrentSuspectedFlag=optIfOTSnSrcCurrentSuspectedFlag, optIfOChSrcPrevDaySuspectedFlag=optIfOChSrcPrevDaySuspectedFlag, optIfOMSnSrcPrevDayLowOutputPower=optIfOMSnSrcPrevDayLowOutputPower, optIfODUkTNimTcmField=optIfODUkTNimTcmField, optIfOMSnSinkCurrentSuspectedFlag=optIfOMSnSinkCurrentSuspectedFlag, optIfOChGroupSrcIntervalHighOutputPower=optIfOChGroupSrcIntervalHighOutputPower, optIfOChGroupSinkCurDayLowOutputPower=optIfOChGroupSinkCurDayLowOutputPower, optIfOTSnConfigTable=optIfOTSnConfigTable, optIfOTUkDEGM=optIfOTUkDEGM, optIfOTSnSrcPrevDayLastInputPower=optIfOTSnSrcPrevDayLastInputPower, OptIfExDAPI=OptIfExDAPI, optIfOTSnSrcPrevDayHighOutputPower=optIfOTSnSrcPrevDayHighOutputPower, optIfOMSnSrcCurDayEntry=optIfOMSnSrcCurDayEntry, optIfOMSnSrcPrevDayLastAggregatedInputPower=optIfOMSnSrcPrevDayLastAggregatedInputPower, optIfOMSnSinkIntervalLowOutputPower=optIfOMSnSinkIntervalLowOutputPower, optIfOChSinkPreOtnPMThresholdGroup=optIfOChSinkPreOtnPMThresholdGroup, optIfOTUkSinkAdaptActive=optIfOTUkSinkAdaptActive, optIfOChGroupSinkCurrentAggregatedInputPower=optIfOChGroupSinkCurrentAggregatedInputPower, optIfOMSnSrcCurrentTable=optIfOMSnSrcCurrentTable, optIfOChGroupSrcCurDaySuspectedFlag=optIfOChGroupSrcCurDaySuspectedFlag, optIfOTSnSourcePreOtnPMGroup=optIfOTSnSourcePreOtnPMGroup, optIfOTSnSrcIntervalHighOutputPower=optIfOTSnSrcIntervalHighOutputPower, optIfOMSnSrcIntervalLowAggregatedInputPower=optIfOMSnSrcIntervalLowAggregatedInputPower, optIfOChSrcCurrentLowOutputPower=optIfOChSrcCurrentLowOutputPower, optIfOChGroupSinkIntervalHighOutputPower=optIfOChGroupSinkIntervalHighOutputPower, optIfOtnConfigCompl=optIfOtnConfigCompl, optIfOTSnSrcPrevDaySuspectedFlag=optIfOTSnSrcPrevDaySuspectedFlag, optIfOChGroup=optIfOChGroup, optIfODUkTSinkGroupCtp=optIfODUkTSinkGroupCtp, optIfOTSnSrcIntervalTable=optIfOTSnSrcIntervalTable, optIfOTUkSAPIExpected=optIfOTUkSAPIExpected, optIfOChGroupSinkCurrentOutputPower=optIfOChGroupSinkCurrentOutputPower, optIfOMSnDirectionality=optIfOMSnDirectionality, optIfOTSnAprStatus=optIfOTSnAprStatus, optIfOMSnSrcCurrentHighOutputPower=optIfOMSnSrcCurrentHighOutputPower, optIfOChGroupConfigTable=optIfOChGroupConfigTable, optIfOTSnSrcIntervalLastOutputPower=optIfOTSnSrcIntervalLastOutputPower, optIfODUkBitRateK=optIfODUkBitRateK, optIfODUkNimSAPIExpected=optIfODUkNimSAPIExpected, optIfOTSnSrcCurrentHighInputPower=optIfOTSnSrcCurrentHighInputPower, optIfOMSnSrcIntervalHighOutputPower=optIfOMSnSrcIntervalHighOutputPower, optIfGroups=optIfGroups, optIfOMSnSinkCurrentUpperInputPowerThreshold=optIfOMSnSinkCurrentUpperInputPowerThreshold, optIfOTSnSrcPrevDayHighInputPower=optIfOTSnSrcPrevDayHighInputPower, optIfOChSinkCurDayHighInputPower=optIfOChSinkCurDayHighInputPower, optIfOTSnTIMDetMode=optIfOTSnTIMDetMode, optIfOMSnSinkCurDayHighOutputPower=optIfOMSnSinkCurDayHighOutputPower, optIfPerfMon=optIfPerfMon, optIfOTSnSinkGroupFull=optIfOTSnSinkGroupFull, optIfOChGroupSrcCurrentHighOutputPower=optIfOChGroupSrcCurrentHighOutputPower, optIfGCC12Group=optIfGCC12Group, optIfOMSnSinkIntervalNumber=optIfOMSnSinkIntervalNumber, optIfOTUkConfigTable=optIfOTUkConfigTable, optIfOTMnReduced=optIfOTMnReduced, optIfODUk=optIfODUk, optIfOChGroupSinkCurrentHighOutputPower=optIfOChGroupSinkCurrentHighOutputPower)
